/****************************************************************************
** Meta object code from reading C++ file 'qdeclarativevideooutput_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/qtmultimediaquicktools/qdeclarativevideooutput_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qdeclarativevideooutput_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QDeclarativeVideoOutput_t {
    QByteArrayData data[45];
    char stringdata0[752];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QDeclarativeVideoOutput_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QDeclarativeVideoOutput_t qt_meta_stringdata_QDeclarativeVideoOutput = {
    {
QT_MOC_LITERAL(0, 0, 23), // "QDeclarativeVideoOutput"
QT_MOC_LITERAL(1, 24, 13), // "sourceChanged"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 15), // "fillModeChanged"
QT_MOC_LITERAL(4, 55, 33), // "QDeclarativeVideoOutput::Fill..."
QT_MOC_LITERAL(5, 89, 18), // "orientationChanged"
QT_MOC_LITERAL(6, 108, 22), // "autoOrientationChanged"
QT_MOC_LITERAL(7, 131, 17), // "sourceRectChanged"
QT_MOC_LITERAL(8, 149, 18), // "contentRectChanged"
QT_MOC_LITERAL(9, 168, 16), // "flushModeChanged"
QT_MOC_LITERAL(10, 185, 20), // "_q_updateMediaObject"
QT_MOC_LITERAL(11, 206, 19), // "_q_updateCameraInfo"
QT_MOC_LITERAL(12, 226, 19), // "_q_updateNativeSize"
QT_MOC_LITERAL(13, 246, 17), // "_q_updateGeometry"
QT_MOC_LITERAL(14, 264, 27), // "_q_screenOrientationChanged"
QT_MOC_LITERAL(15, 292, 23), // "_q_invalidateSceneGraph"
QT_MOC_LITERAL(16, 316, 14), // "mapPointToItem"
QT_MOC_LITERAL(17, 331, 5), // "point"
QT_MOC_LITERAL(18, 337, 13), // "mapRectToItem"
QT_MOC_LITERAL(19, 351, 9), // "rectangle"
QT_MOC_LITERAL(20, 361, 24), // "mapNormalizedPointToItem"
QT_MOC_LITERAL(21, 386, 23), // "mapNormalizedRectToItem"
QT_MOC_LITERAL(22, 410, 16), // "mapPointToSource"
QT_MOC_LITERAL(23, 427, 15), // "mapRectToSource"
QT_MOC_LITERAL(24, 443, 26), // "mapPointToSourceNormalized"
QT_MOC_LITERAL(25, 470, 25), // "mapRectToSourceNormalized"
QT_MOC_LITERAL(26, 496, 6), // "source"
QT_MOC_LITERAL(27, 503, 8), // "fillMode"
QT_MOC_LITERAL(28, 512, 8), // "FillMode"
QT_MOC_LITERAL(29, 521, 11), // "orientation"
QT_MOC_LITERAL(30, 533, 15), // "autoOrientation"
QT_MOC_LITERAL(31, 549, 10), // "sourceRect"
QT_MOC_LITERAL(32, 560, 11), // "contentRect"
QT_MOC_LITERAL(33, 572, 7), // "filters"
QT_MOC_LITERAL(34, 580, 38), // "QQmlListProperty<QAbstractVid..."
QT_MOC_LITERAL(35, 619, 9), // "flushMode"
QT_MOC_LITERAL(36, 629, 9), // "FlushMode"
QT_MOC_LITERAL(37, 639, 12), // "videoSurface"
QT_MOC_LITERAL(38, 652, 22), // "QAbstractVideoSurface*"
QT_MOC_LITERAL(39, 675, 10), // "EmptyFrame"
QT_MOC_LITERAL(40, 686, 10), // "FirstFrame"
QT_MOC_LITERAL(41, 697, 9), // "LastFrame"
QT_MOC_LITERAL(42, 707, 7), // "Stretch"
QT_MOC_LITERAL(43, 715, 17), // "PreserveAspectFit"
QT_MOC_LITERAL(44, 733, 18) // "PreserveAspectCrop"

    },
    "QDeclarativeVideoOutput\0sourceChanged\0"
    "\0fillModeChanged\0QDeclarativeVideoOutput::FillMode\0"
    "orientationChanged\0autoOrientationChanged\0"
    "sourceRectChanged\0contentRectChanged\0"
    "flushModeChanged\0_q_updateMediaObject\0"
    "_q_updateCameraInfo\0_q_updateNativeSize\0"
    "_q_updateGeometry\0_q_screenOrientationChanged\0"
    "_q_invalidateSceneGraph\0mapPointToItem\0"
    "point\0mapRectToItem\0rectangle\0"
    "mapNormalizedPointToItem\0"
    "mapNormalizedRectToItem\0mapPointToSource\0"
    "mapRectToSource\0mapPointToSourceNormalized\0"
    "mapRectToSourceNormalized\0source\0"
    "fillMode\0FillMode\0orientation\0"
    "autoOrientation\0sourceRect\0contentRect\0"
    "filters\0QQmlListProperty<QAbstractVideoFilter>\0"
    "flushMode\0FlushMode\0videoSurface\0"
    "QAbstractVideoSurface*\0EmptyFrame\0"
    "FirstFrame\0LastFrame\0Stretch\0"
    "PreserveAspectFit\0PreserveAspectCrop"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QDeclarativeVideoOutput[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       9,  160, // properties
       2,  205, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  119,    2, 0x06 /* Public */,
       3,    1,  120,    2, 0x06 /* Public */,
       5,    0,  123,    2, 0x06 /* Public */,
       6,    0,  124,    2, 0x06 /* Public */,
       7,    0,  125,    2, 0x06 /* Public */,
       8,    0,  126,    2, 0x06 /* Public */,
       9,    0,  127,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    0,  128,    2, 0x08 /* Private */,
      11,    0,  129,    2, 0x08 /* Private */,
      12,    0,  130,    2, 0x08 /* Private */,
      13,    0,  131,    2, 0x08 /* Private */,
      14,    1,  132,    2, 0x08 /* Private */,
      15,    0,  135,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      16,    1,  136,    2, 0x02 /* Public */,
      18,    1,  139,    2, 0x02 /* Public */,
      20,    1,  142,    2, 0x02 /* Public */,
      21,    1,  145,    2, 0x02 /* Public */,
      22,    1,  148,    2, 0x02 /* Public */,
      23,    1,  151,    2, 0x02 /* Public */,
      24,    1,  154,    2, 0x02 /* Public */,
      25,    1,  157,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,

 // methods: parameters
    QMetaType::QPointF, QMetaType::QPointF,   17,
    QMetaType::QRectF, QMetaType::QRectF,   19,
    QMetaType::QPointF, QMetaType::QPointF,   17,
    QMetaType::QRectF, QMetaType::QRectF,   19,
    QMetaType::QPointF, QMetaType::QPointF,   17,
    QMetaType::QRectF, QMetaType::QRectF,   19,
    QMetaType::QPointF, QMetaType::QPointF,   17,
    QMetaType::QRectF, QMetaType::QRectF,   19,

 // properties: name, type, flags
      26, QMetaType::QObjectStar, 0x00495103,
      27, 0x80000000 | 28, 0x0049510b,
      29, QMetaType::Int, 0x00495103,
      30, QMetaType::Bool, 0x00c95103,
      31, QMetaType::QRectF, 0x00495001,
      32, QMetaType::QRectF, 0x00495001,
      33, 0x80000000 | 34, 0x00095009,
      35, 0x80000000 | 36, 0x00c9510b,
      37, 0x80000000 | 38, 0x00895409,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,
       0,
       6,
       0,

 // properties: revision
       0,
       0,
       0,
       2,
       0,
       0,
       0,
      13,
      15,

 // enums: name, alias, flags, count, data
      36,   36, 0x0,    3,  215,
      28,   28, 0x0,    3,  221,

 // enum data: key, value
      39, uint(QDeclarativeVideoOutput::EmptyFrame),
      40, uint(QDeclarativeVideoOutput::FirstFrame),
      41, uint(QDeclarativeVideoOutput::LastFrame),
      42, uint(QDeclarativeVideoOutput::Stretch),
      43, uint(QDeclarativeVideoOutput::PreserveAspectFit),
      44, uint(QDeclarativeVideoOutput::PreserveAspectCrop),

       0        // eod
};

void QDeclarativeVideoOutput::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QDeclarativeVideoOutput *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->sourceChanged(); break;
        case 1: _t->fillModeChanged((*reinterpret_cast< QDeclarativeVideoOutput::FillMode(*)>(_a[1]))); break;
        case 2: _t->orientationChanged(); break;
        case 3: _t->autoOrientationChanged(); break;
        case 4: _t->sourceRectChanged(); break;
        case 5: _t->contentRectChanged(); break;
        case 6: _t->flushModeChanged(); break;
        case 7: _t->_q_updateMediaObject(); break;
        case 8: _t->_q_updateCameraInfo(); break;
        case 9: _t->_q_updateNativeSize(); break;
        case 10: _t->_q_updateGeometry(); break;
        case 11: _t->_q_screenOrientationChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->_q_invalidateSceneGraph(); break;
        case 13: { QPointF _r = _t->mapPointToItem((*reinterpret_cast< const QPointF(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QPointF*>(_a[0]) = std::move(_r); }  break;
        case 14: { QRectF _r = _t->mapRectToItem((*reinterpret_cast< const QRectF(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QRectF*>(_a[0]) = std::move(_r); }  break;
        case 15: { QPointF _r = _t->mapNormalizedPointToItem((*reinterpret_cast< const QPointF(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QPointF*>(_a[0]) = std::move(_r); }  break;
        case 16: { QRectF _r = _t->mapNormalizedRectToItem((*reinterpret_cast< const QRectF(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QRectF*>(_a[0]) = std::move(_r); }  break;
        case 17: { QPointF _r = _t->mapPointToSource((*reinterpret_cast< const QPointF(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QPointF*>(_a[0]) = std::move(_r); }  break;
        case 18: { QRectF _r = _t->mapRectToSource((*reinterpret_cast< const QRectF(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QRectF*>(_a[0]) = std::move(_r); }  break;
        case 19: { QPointF _r = _t->mapPointToSourceNormalized((*reinterpret_cast< const QPointF(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QPointF*>(_a[0]) = std::move(_r); }  break;
        case 20: { QRectF _r = _t->mapRectToSourceNormalized((*reinterpret_cast< const QRectF(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QRectF*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QDeclarativeVideoOutput::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeVideoOutput::sourceChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QDeclarativeVideoOutput::*)(QDeclarativeVideoOutput::FillMode );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeVideoOutput::fillModeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QDeclarativeVideoOutput::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeVideoOutput::orientationChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QDeclarativeVideoOutput::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeVideoOutput::autoOrientationChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QDeclarativeVideoOutput::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeVideoOutput::sourceRectChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QDeclarativeVideoOutput::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeVideoOutput::contentRectChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QDeclarativeVideoOutput::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeVideoOutput::flushModeChanged)) {
                *result = 6;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QDeclarativeVideoOutput *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QObject**>(_v) = _t->source(); break;
        case 1: *reinterpret_cast< FillMode*>(_v) = _t->fillMode(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->orientation(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->autoOrientation(); break;
        case 4: *reinterpret_cast< QRectF*>(_v) = _t->sourceRect(); break;
        case 5: *reinterpret_cast< QRectF*>(_v) = _t->contentRect(); break;
        case 6: *reinterpret_cast< QQmlListProperty<QAbstractVideoFilter>*>(_v) = _t->filters(); break;
        case 7: *reinterpret_cast< FlushMode*>(_v) = _t->flushMode(); break;
        case 8: *reinterpret_cast< QAbstractVideoSurface**>(_v) = _t->videoSurface(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QDeclarativeVideoOutput *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSource(*reinterpret_cast< QObject**>(_v)); break;
        case 1: _t->setFillMode(*reinterpret_cast< FillMode*>(_v)); break;
        case 2: _t->setOrientation(*reinterpret_cast< int*>(_v)); break;
        case 3: _t->setAutoOrientation(*reinterpret_cast< bool*>(_v)); break;
        case 7: _t->setFlushMode(*reinterpret_cast< FlushMode*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QDeclarativeVideoOutput::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_meta_stringdata_QDeclarativeVideoOutput.data,
    qt_meta_data_QDeclarativeVideoOutput,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QDeclarativeVideoOutput::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QDeclarativeVideoOutput::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QDeclarativeVideoOutput.stringdata0))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int QDeclarativeVideoOutput::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 21;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 9;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 9;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QDeclarativeVideoOutput::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QDeclarativeVideoOutput::fillModeChanged(QDeclarativeVideoOutput::FillMode _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QDeclarativeVideoOutput::orientationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QDeclarativeVideoOutput::autoOrientationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QDeclarativeVideoOutput::sourceRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QDeclarativeVideoOutput::contentRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QDeclarativeVideoOutput::flushModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
