/****************************************************************************
** Meta object code from reading C++ file 'qdeclarativemediametadata_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../git/src/imports/multimedia/qdeclarativemediametadata_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qdeclarativemediametadata_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QDeclarativeMediaMetaData_t {
    QByteArrayData data[91];
    char stringdata0[1107];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QDeclarativeMediaMetaData_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QDeclarativeMediaMetaData_t qt_meta_stringdata_QDeclarativeMediaMetaData = {
    {
QT_MOC_LITERAL(0, 0, 25), // "QDeclarativeMediaMetaData"
QT_MOC_LITERAL(1, 26, 15), // "metaDataChanged"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 5), // "title"
QT_MOC_LITERAL(4, 49, 8), // "subTitle"
QT_MOC_LITERAL(5, 58, 6), // "author"
QT_MOC_LITERAL(6, 65, 7), // "comment"
QT_MOC_LITERAL(7, 73, 11), // "description"
QT_MOC_LITERAL(8, 85, 8), // "category"
QT_MOC_LITERAL(9, 94, 5), // "genre"
QT_MOC_LITERAL(10, 100, 4), // "year"
QT_MOC_LITERAL(11, 105, 4), // "date"
QT_MOC_LITERAL(12, 110, 10), // "userRating"
QT_MOC_LITERAL(13, 121, 8), // "keywords"
QT_MOC_LITERAL(14, 130, 8), // "language"
QT_MOC_LITERAL(15, 139, 9), // "publisher"
QT_MOC_LITERAL(16, 149, 9), // "copyright"
QT_MOC_LITERAL(17, 159, 14), // "parentalRating"
QT_MOC_LITERAL(18, 174, 18), // "ratingOrganization"
QT_MOC_LITERAL(19, 193, 4), // "size"
QT_MOC_LITERAL(20, 198, 9), // "mediaType"
QT_MOC_LITERAL(21, 208, 8), // "duration"
QT_MOC_LITERAL(22, 217, 12), // "audioBitRate"
QT_MOC_LITERAL(23, 230, 10), // "audioCodec"
QT_MOC_LITERAL(24, 241, 12), // "averageLevel"
QT_MOC_LITERAL(25, 254, 12), // "channelCount"
QT_MOC_LITERAL(26, 267, 9), // "peakValue"
QT_MOC_LITERAL(27, 277, 10), // "sampleRate"
QT_MOC_LITERAL(28, 288, 10), // "albumTitle"
QT_MOC_LITERAL(29, 299, 11), // "albumArtist"
QT_MOC_LITERAL(30, 311, 18), // "contributingArtist"
QT_MOC_LITERAL(31, 330, 8), // "composer"
QT_MOC_LITERAL(32, 339, 9), // "conductor"
QT_MOC_LITERAL(33, 349, 6), // "lyrics"
QT_MOC_LITERAL(34, 356, 4), // "mood"
QT_MOC_LITERAL(35, 361, 11), // "trackNumber"
QT_MOC_LITERAL(36, 373, 10), // "trackCount"
QT_MOC_LITERAL(37, 384, 16), // "coverArtUrlSmall"
QT_MOC_LITERAL(38, 401, 16), // "coverArtUrlLarge"
QT_MOC_LITERAL(39, 418, 10), // "resolution"
QT_MOC_LITERAL(40, 429, 16), // "pixelAspectRatio"
QT_MOC_LITERAL(41, 446, 14), // "videoFrameRate"
QT_MOC_LITERAL(42, 461, 12), // "videoBitRate"
QT_MOC_LITERAL(43, 474, 10), // "videoCodec"
QT_MOC_LITERAL(44, 485, 9), // "posterUrl"
QT_MOC_LITERAL(45, 495, 13), // "chapterNumber"
QT_MOC_LITERAL(46, 509, 8), // "director"
QT_MOC_LITERAL(47, 518, 13), // "leadPerformer"
QT_MOC_LITERAL(48, 532, 6), // "writer"
QT_MOC_LITERAL(49, 539, 18), // "cameraManufacturer"
QT_MOC_LITERAL(50, 558, 11), // "cameraModel"
QT_MOC_LITERAL(51, 570, 5), // "event"
QT_MOC_LITERAL(52, 576, 7), // "subject"
QT_MOC_LITERAL(53, 584, 11), // "orientation"
QT_MOC_LITERAL(54, 596, 12), // "exposureTime"
QT_MOC_LITERAL(55, 609, 7), // "fNumber"
QT_MOC_LITERAL(56, 617, 15), // "exposureProgram"
QT_MOC_LITERAL(57, 633, 15), // "isoSpeedRatings"
QT_MOC_LITERAL(58, 649, 17), // "exposureBiasValue"
QT_MOC_LITERAL(59, 667, 16), // "dateTimeOriginal"
QT_MOC_LITERAL(60, 684, 17), // "dateTimeDigitized"
QT_MOC_LITERAL(61, 702, 15), // "subjectDistance"
QT_MOC_LITERAL(62, 718, 12), // "meteringMode"
QT_MOC_LITERAL(63, 731, 11), // "lightSource"
QT_MOC_LITERAL(64, 743, 5), // "flash"
QT_MOC_LITERAL(65, 749, 11), // "focalLength"
QT_MOC_LITERAL(66, 761, 12), // "exposureMode"
QT_MOC_LITERAL(67, 774, 12), // "whiteBalance"
QT_MOC_LITERAL(68, 787, 16), // "digitalZoomRatio"
QT_MOC_LITERAL(69, 804, 21), // "focalLengthIn35mmFilm"
QT_MOC_LITERAL(70, 826, 16), // "sceneCaptureType"
QT_MOC_LITERAL(71, 843, 11), // "gainControl"
QT_MOC_LITERAL(72, 855, 8), // "contrast"
QT_MOC_LITERAL(73, 864, 10), // "saturation"
QT_MOC_LITERAL(74, 875, 9), // "sharpness"
QT_MOC_LITERAL(75, 885, 24), // "deviceSettingDescription"
QT_MOC_LITERAL(76, 910, 11), // "gpsLatitude"
QT_MOC_LITERAL(77, 922, 12), // "gpsLongitude"
QT_MOC_LITERAL(78, 935, 11), // "gpsAltitude"
QT_MOC_LITERAL(79, 947, 12), // "gpsTimeStamp"
QT_MOC_LITERAL(80, 960, 13), // "gpsSatellites"
QT_MOC_LITERAL(81, 974, 9), // "gpsStatus"
QT_MOC_LITERAL(82, 984, 6), // "gpsDOP"
QT_MOC_LITERAL(83, 991, 8), // "gpsSpeed"
QT_MOC_LITERAL(84, 1000, 8), // "gpsTrack"
QT_MOC_LITERAL(85, 1009, 11), // "gpsTrackRef"
QT_MOC_LITERAL(86, 1021, 15), // "gpsImgDirection"
QT_MOC_LITERAL(87, 1037, 18), // "gpsImgDirectionRef"
QT_MOC_LITERAL(88, 1056, 11), // "gpsMapDatum"
QT_MOC_LITERAL(89, 1068, 19), // "gpsProcessingMethod"
QT_MOC_LITERAL(90, 1088, 18) // "gpsAreaInformation"

    },
    "QDeclarativeMediaMetaData\0metaDataChanged\0"
    "\0title\0subTitle\0author\0comment\0"
    "description\0category\0genre\0year\0date\0"
    "userRating\0keywords\0language\0publisher\0"
    "copyright\0parentalRating\0ratingOrganization\0"
    "size\0mediaType\0duration\0audioBitRate\0"
    "audioCodec\0averageLevel\0channelCount\0"
    "peakValue\0sampleRate\0albumTitle\0"
    "albumArtist\0contributingArtist\0composer\0"
    "conductor\0lyrics\0mood\0trackNumber\0"
    "trackCount\0coverArtUrlSmall\0"
    "coverArtUrlLarge\0resolution\0"
    "pixelAspectRatio\0videoFrameRate\0"
    "videoBitRate\0videoCodec\0posterUrl\0"
    "chapterNumber\0director\0leadPerformer\0"
    "writer\0cameraManufacturer\0cameraModel\0"
    "event\0subject\0orientation\0exposureTime\0"
    "fNumber\0exposureProgram\0isoSpeedRatings\0"
    "exposureBiasValue\0dateTimeOriginal\0"
    "dateTimeDigitized\0subjectDistance\0"
    "meteringMode\0lightSource\0flash\0"
    "focalLength\0exposureMode\0whiteBalance\0"
    "digitalZoomRatio\0focalLengthIn35mmFilm\0"
    "sceneCaptureType\0gainControl\0contrast\0"
    "saturation\0sharpness\0deviceSettingDescription\0"
    "gpsLatitude\0gpsLongitude\0gpsAltitude\0"
    "gpsTimeStamp\0gpsSatellites\0gpsStatus\0"
    "gpsDOP\0gpsSpeed\0gpsTrack\0gpsTrackRef\0"
    "gpsImgDirection\0gpsImgDirectionRef\0"
    "gpsMapDatum\0gpsProcessingMethod\0"
    "gpsAreaInformation"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QDeclarativeMediaMetaData[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
      88,   20, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,

 // properties: name, type, flags
       3, QMetaType::QVariant, 0x00495103,
       4, QMetaType::QVariant, 0x00495103,
       5, QMetaType::QVariant, 0x00495103,
       6, QMetaType::QVariant, 0x00495103,
       7, QMetaType::QVariant, 0x00495103,
       8, QMetaType::QVariant, 0x00495103,
       9, QMetaType::QVariant, 0x00495103,
      10, QMetaType::QVariant, 0x00495103,
      11, QMetaType::QVariant, 0x00495103,
      12, QMetaType::QVariant, 0x00495103,
      13, QMetaType::QVariant, 0x00495103,
      14, QMetaType::QVariant, 0x00495103,
      15, QMetaType::QVariant, 0x00495103,
      16, QMetaType::QVariant, 0x00495103,
      17, QMetaType::QVariant, 0x00495103,
      18, QMetaType::QVariant, 0x00495103,
      19, QMetaType::QVariant, 0x00495103,
      20, QMetaType::QVariant, 0x00495103,
      21, QMetaType::QVariant, 0x00495103,
      22, QMetaType::QVariant, 0x00495103,
      23, QMetaType::QVariant, 0x00495103,
      24, QMetaType::QVariant, 0x00495103,
      25, QMetaType::QVariant, 0x00495103,
      26, QMetaType::QVariant, 0x00495103,
      27, QMetaType::QVariant, 0x00495103,
      28, QMetaType::QVariant, 0x00495103,
      29, QMetaType::QVariant, 0x00495103,
      30, QMetaType::QVariant, 0x00495103,
      31, QMetaType::QVariant, 0x00495103,
      32, QMetaType::QVariant, 0x00495103,
      33, QMetaType::QVariant, 0x00495103,
      34, QMetaType::QVariant, 0x00495103,
      35, QMetaType::QVariant, 0x00495103,
      36, QMetaType::QVariant, 0x00495103,
      37, QMetaType::QVariant, 0x00495103,
      38, QMetaType::QVariant, 0x00495103,
      39, QMetaType::QVariant, 0x00495103,
      40, QMetaType::QVariant, 0x00495103,
      41, QMetaType::QVariant, 0x00495103,
      42, QMetaType::QVariant, 0x00495103,
      43, QMetaType::QVariant, 0x00495103,
      44, QMetaType::QVariant, 0x00495103,
      45, QMetaType::QVariant, 0x00495103,
      46, QMetaType::QVariant, 0x00495103,
      47, QMetaType::QVariant, 0x00495103,
      48, QMetaType::QVariant, 0x00495103,
      49, QMetaType::QVariant, 0x00495103,
      50, QMetaType::QVariant, 0x00495103,
      51, QMetaType::QVariant, 0x00495103,
      52, QMetaType::QVariant, 0x00495103,
      53, QMetaType::QVariant, 0x00495103,
      54, QMetaType::QVariant, 0x00495103,
      55, QMetaType::QVariant, 0x00495103,
      56, QMetaType::QVariant, 0x00495103,
      57, QMetaType::QVariant, 0x00495003,
      58, QMetaType::QVariant, 0x00495103,
      59, QMetaType::QVariant, 0x00495103,
      60, QMetaType::QVariant, 0x00495103,
      61, QMetaType::QVariant, 0x00495103,
      62, QMetaType::QVariant, 0x00495103,
      63, QMetaType::QVariant, 0x00495103,
      64, QMetaType::QVariant, 0x00495103,
      65, QMetaType::QVariant, 0x00495103,
      66, QMetaType::QVariant, 0x00495103,
      67, QMetaType::QVariant, 0x00495103,
      68, QMetaType::QVariant, 0x00495103,
      69, QMetaType::QVariant, 0x00495103,
      70, QMetaType::QVariant, 0x00495103,
      71, QMetaType::QVariant, 0x00495103,
      72, QMetaType::QVariant, 0x00495103,
      73, QMetaType::QVariant, 0x00495103,
      74, QMetaType::QVariant, 0x00495103,
      75, QMetaType::QVariant, 0x00495103,
      76, QMetaType::QVariant, 0x00495003,
      77, QMetaType::QVariant, 0x00495003,
      78, QMetaType::QVariant, 0x00495003,
      79, QMetaType::QVariant, 0x00495003,
      80, QMetaType::QVariant, 0x00495003,
      81, QMetaType::QVariant, 0x00495003,
      82, QMetaType::QVariant, 0x00495003,
      83, QMetaType::QVariant, 0x00495003,
      84, QMetaType::QVariant, 0x00495003,
      85, QMetaType::QVariant, 0x00495003,
      86, QMetaType::QVariant, 0x00495003,
      87, QMetaType::QVariant, 0x00495003,
      88, QMetaType::QVariant, 0x00495003,
      89, QMetaType::QVariant, 0x00495003,
      90, QMetaType::QVariant, 0x00495003,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,

       0        // eod
};

void QDeclarativeMediaMetaData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QDeclarativeMediaMetaData *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->metaDataChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QDeclarativeMediaMetaData::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeMediaMetaData::metaDataChanged)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QDeclarativeMediaMetaData *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QVariant*>(_v) = _t->title(); break;
        case 1: *reinterpret_cast< QVariant*>(_v) = _t->subTitle(); break;
        case 2: *reinterpret_cast< QVariant*>(_v) = _t->author(); break;
        case 3: *reinterpret_cast< QVariant*>(_v) = _t->comment(); break;
        case 4: *reinterpret_cast< QVariant*>(_v) = _t->description(); break;
        case 5: *reinterpret_cast< QVariant*>(_v) = _t->category(); break;
        case 6: *reinterpret_cast< QVariant*>(_v) = _t->genre(); break;
        case 7: *reinterpret_cast< QVariant*>(_v) = _t->year(); break;
        case 8: *reinterpret_cast< QVariant*>(_v) = _t->date(); break;
        case 9: *reinterpret_cast< QVariant*>(_v) = _t->userRating(); break;
        case 10: *reinterpret_cast< QVariant*>(_v) = _t->keywords(); break;
        case 11: *reinterpret_cast< QVariant*>(_v) = _t->language(); break;
        case 12: *reinterpret_cast< QVariant*>(_v) = _t->publisher(); break;
        case 13: *reinterpret_cast< QVariant*>(_v) = _t->copyright(); break;
        case 14: *reinterpret_cast< QVariant*>(_v) = _t->parentalRating(); break;
        case 15: *reinterpret_cast< QVariant*>(_v) = _t->ratingOrganization(); break;
        case 16: *reinterpret_cast< QVariant*>(_v) = _t->size(); break;
        case 17: *reinterpret_cast< QVariant*>(_v) = _t->mediaType(); break;
        case 18: *reinterpret_cast< QVariant*>(_v) = _t->duration(); break;
        case 19: *reinterpret_cast< QVariant*>(_v) = _t->audioBitRate(); break;
        case 20: *reinterpret_cast< QVariant*>(_v) = _t->audioCodec(); break;
        case 21: *reinterpret_cast< QVariant*>(_v) = _t->averageLevel(); break;
        case 22: *reinterpret_cast< QVariant*>(_v) = _t->channelCount(); break;
        case 23: *reinterpret_cast< QVariant*>(_v) = _t->peakValue(); break;
        case 24: *reinterpret_cast< QVariant*>(_v) = _t->sampleRate(); break;
        case 25: *reinterpret_cast< QVariant*>(_v) = _t->albumTitle(); break;
        case 26: *reinterpret_cast< QVariant*>(_v) = _t->albumArtist(); break;
        case 27: *reinterpret_cast< QVariant*>(_v) = _t->contributingArtist(); break;
        case 28: *reinterpret_cast< QVariant*>(_v) = _t->composer(); break;
        case 29: *reinterpret_cast< QVariant*>(_v) = _t->conductor(); break;
        case 30: *reinterpret_cast< QVariant*>(_v) = _t->lyrics(); break;
        case 31: *reinterpret_cast< QVariant*>(_v) = _t->mood(); break;
        case 32: *reinterpret_cast< QVariant*>(_v) = _t->trackNumber(); break;
        case 33: *reinterpret_cast< QVariant*>(_v) = _t->trackCount(); break;
        case 34: *reinterpret_cast< QVariant*>(_v) = _t->coverArtUrlSmall(); break;
        case 35: *reinterpret_cast< QVariant*>(_v) = _t->coverArtUrlLarge(); break;
        case 36: *reinterpret_cast< QVariant*>(_v) = _t->resolution(); break;
        case 37: *reinterpret_cast< QVariant*>(_v) = _t->pixelAspectRatio(); break;
        case 38: *reinterpret_cast< QVariant*>(_v) = _t->videoFrameRate(); break;
        case 39: *reinterpret_cast< QVariant*>(_v) = _t->videoBitRate(); break;
        case 40: *reinterpret_cast< QVariant*>(_v) = _t->videoCodec(); break;
        case 41: *reinterpret_cast< QVariant*>(_v) = _t->posterUrl(); break;
        case 42: *reinterpret_cast< QVariant*>(_v) = _t->chapterNumber(); break;
        case 43: *reinterpret_cast< QVariant*>(_v) = _t->director(); break;
        case 44: *reinterpret_cast< QVariant*>(_v) = _t->leadPerformer(); break;
        case 45: *reinterpret_cast< QVariant*>(_v) = _t->writer(); break;
        case 46: *reinterpret_cast< QVariant*>(_v) = _t->cameraManufacturer(); break;
        case 47: *reinterpret_cast< QVariant*>(_v) = _t->cameraModel(); break;
        case 48: *reinterpret_cast< QVariant*>(_v) = _t->event(); break;
        case 49: *reinterpret_cast< QVariant*>(_v) = _t->subject(); break;
        case 50: *reinterpret_cast< QVariant*>(_v) = _t->orientation(); break;
        case 51: *reinterpret_cast< QVariant*>(_v) = _t->exposureTime(); break;
        case 52: *reinterpret_cast< QVariant*>(_v) = _t->fNumber(); break;
        case 53: *reinterpret_cast< QVariant*>(_v) = _t->exposureProgram(); break;
        case 54: *reinterpret_cast< QVariant*>(_v) = _t->isoSpeedRatings(); break;
        case 55: *reinterpret_cast< QVariant*>(_v) = _t->exposureBiasValue(); break;
        case 56: *reinterpret_cast< QVariant*>(_v) = _t->dateTimeOriginal(); break;
        case 57: *reinterpret_cast< QVariant*>(_v) = _t->dateTimeDigitized(); break;
        case 58: *reinterpret_cast< QVariant*>(_v) = _t->subjectDistance(); break;
        case 59: *reinterpret_cast< QVariant*>(_v) = _t->meteringMode(); break;
        case 60: *reinterpret_cast< QVariant*>(_v) = _t->lightSource(); break;
        case 61: *reinterpret_cast< QVariant*>(_v) = _t->flash(); break;
        case 62: *reinterpret_cast< QVariant*>(_v) = _t->focalLength(); break;
        case 63: *reinterpret_cast< QVariant*>(_v) = _t->exposureMode(); break;
        case 64: *reinterpret_cast< QVariant*>(_v) = _t->whiteBalance(); break;
        case 65: *reinterpret_cast< QVariant*>(_v) = _t->digitalZoomRatio(); break;
        case 66: *reinterpret_cast< QVariant*>(_v) = _t->focalLengthIn35mmFilm(); break;
        case 67: *reinterpret_cast< QVariant*>(_v) = _t->sceneCaptureType(); break;
        case 68: *reinterpret_cast< QVariant*>(_v) = _t->gainControl(); break;
        case 69: *reinterpret_cast< QVariant*>(_v) = _t->contrast(); break;
        case 70: *reinterpret_cast< QVariant*>(_v) = _t->saturation(); break;
        case 71: *reinterpret_cast< QVariant*>(_v) = _t->sharpness(); break;
        case 72: *reinterpret_cast< QVariant*>(_v) = _t->deviceSettingDescription(); break;
        case 73: *reinterpret_cast< QVariant*>(_v) = _t->gpsLatitude(); break;
        case 74: *reinterpret_cast< QVariant*>(_v) = _t->gpsLongitude(); break;
        case 75: *reinterpret_cast< QVariant*>(_v) = _t->gpsAltitude(); break;
        case 76: *reinterpret_cast< QVariant*>(_v) = _t->gpsTimeStamp(); break;
        case 77: *reinterpret_cast< QVariant*>(_v) = _t->gpsSatellites(); break;
        case 78: *reinterpret_cast< QVariant*>(_v) = _t->gpsStatus(); break;
        case 79: *reinterpret_cast< QVariant*>(_v) = _t->gpsDOP(); break;
        case 80: *reinterpret_cast< QVariant*>(_v) = _t->gpsSpeed(); break;
        case 81: *reinterpret_cast< QVariant*>(_v) = _t->gpsTrack(); break;
        case 82: *reinterpret_cast< QVariant*>(_v) = _t->gpsTrackRef(); break;
        case 83: *reinterpret_cast< QVariant*>(_v) = _t->gpsImgDirection(); break;
        case 84: *reinterpret_cast< QVariant*>(_v) = _t->gpsImgDirectionRef(); break;
        case 85: *reinterpret_cast< QVariant*>(_v) = _t->gpsMapDatum(); break;
        case 86: *reinterpret_cast< QVariant*>(_v) = _t->gpsProcessingMethod(); break;
        case 87: *reinterpret_cast< QVariant*>(_v) = _t->gpsAreaInformation(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QDeclarativeMediaMetaData *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTitle(*reinterpret_cast< QVariant*>(_v)); break;
        case 1: _t->setSubTitle(*reinterpret_cast< QVariant*>(_v)); break;
        case 2: _t->setAuthor(*reinterpret_cast< QVariant*>(_v)); break;
        case 3: _t->setComment(*reinterpret_cast< QVariant*>(_v)); break;
        case 4: _t->setDescription(*reinterpret_cast< QVariant*>(_v)); break;
        case 5: _t->setCategory(*reinterpret_cast< QVariant*>(_v)); break;
        case 6: _t->setGenre(*reinterpret_cast< QVariant*>(_v)); break;
        case 7: _t->setYear(*reinterpret_cast< QVariant*>(_v)); break;
        case 8: _t->setDate(*reinterpret_cast< QVariant*>(_v)); break;
        case 9: _t->setUserRating(*reinterpret_cast< QVariant*>(_v)); break;
        case 10: _t->setKeywords(*reinterpret_cast< QVariant*>(_v)); break;
        case 11: _t->setLanguage(*reinterpret_cast< QVariant*>(_v)); break;
        case 12: _t->setPublisher(*reinterpret_cast< QVariant*>(_v)); break;
        case 13: _t->setCopyright(*reinterpret_cast< QVariant*>(_v)); break;
        case 14: _t->setParentalRating(*reinterpret_cast< QVariant*>(_v)); break;
        case 15: _t->setRatingOrganization(*reinterpret_cast< QVariant*>(_v)); break;
        case 16: _t->setSize(*reinterpret_cast< QVariant*>(_v)); break;
        case 17: _t->setMediaType(*reinterpret_cast< QVariant*>(_v)); break;
        case 18: _t->setDuration(*reinterpret_cast< QVariant*>(_v)); break;
        case 19: _t->setAudioBitRate(*reinterpret_cast< QVariant*>(_v)); break;
        case 20: _t->setAudioCodec(*reinterpret_cast< QVariant*>(_v)); break;
        case 21: _t->setAverageLevel(*reinterpret_cast< QVariant*>(_v)); break;
        case 22: _t->setChannelCount(*reinterpret_cast< QVariant*>(_v)); break;
        case 23: _t->setPeakValue(*reinterpret_cast< QVariant*>(_v)); break;
        case 24: _t->setSampleRate(*reinterpret_cast< QVariant*>(_v)); break;
        case 25: _t->setAlbumTitle(*reinterpret_cast< QVariant*>(_v)); break;
        case 26: _t->setAlbumArtist(*reinterpret_cast< QVariant*>(_v)); break;
        case 27: _t->setContributingArtist(*reinterpret_cast< QVariant*>(_v)); break;
        case 28: _t->setComposer(*reinterpret_cast< QVariant*>(_v)); break;
        case 29: _t->setConductor(*reinterpret_cast< QVariant*>(_v)); break;
        case 30: _t->setLyrics(*reinterpret_cast< QVariant*>(_v)); break;
        case 31: _t->setMood(*reinterpret_cast< QVariant*>(_v)); break;
        case 32: _t->setTrackNumber(*reinterpret_cast< QVariant*>(_v)); break;
        case 33: _t->setTrackCount(*reinterpret_cast< QVariant*>(_v)); break;
        case 34: _t->setCoverArtUrlSmall(*reinterpret_cast< QVariant*>(_v)); break;
        case 35: _t->setCoverArtUrlLarge(*reinterpret_cast< QVariant*>(_v)); break;
        case 36: _t->setResolution(*reinterpret_cast< QVariant*>(_v)); break;
        case 37: _t->setPixelAspectRatio(*reinterpret_cast< QVariant*>(_v)); break;
        case 38: _t->setVideoFrameRate(*reinterpret_cast< QVariant*>(_v)); break;
        case 39: _t->setVideoBitRate(*reinterpret_cast< QVariant*>(_v)); break;
        case 40: _t->setVideoCodec(*reinterpret_cast< QVariant*>(_v)); break;
        case 41: _t->setPosterUrl(*reinterpret_cast< QVariant*>(_v)); break;
        case 42: _t->setChapterNumber(*reinterpret_cast< QVariant*>(_v)); break;
        case 43: _t->setDirector(*reinterpret_cast< QVariant*>(_v)); break;
        case 44: _t->setLeadPerformer(*reinterpret_cast< QVariant*>(_v)); break;
        case 45: _t->setWriter(*reinterpret_cast< QVariant*>(_v)); break;
        case 46: _t->setCameraManufacturer(*reinterpret_cast< QVariant*>(_v)); break;
        case 47: _t->setCameraModel(*reinterpret_cast< QVariant*>(_v)); break;
        case 48: _t->setEvent(*reinterpret_cast< QVariant*>(_v)); break;
        case 49: _t->setSubject(*reinterpret_cast< QVariant*>(_v)); break;
        case 50: _t->setOrientation(*reinterpret_cast< QVariant*>(_v)); break;
        case 51: _t->setExposureTime(*reinterpret_cast< QVariant*>(_v)); break;
        case 52: _t->setFNumber(*reinterpret_cast< QVariant*>(_v)); break;
        case 53: _t->setExposureProgram(*reinterpret_cast< QVariant*>(_v)); break;
        case 54: _t->setISOSpeedRatings(*reinterpret_cast< QVariant*>(_v)); break;
        case 55: _t->setExposureBiasValue(*reinterpret_cast< QVariant*>(_v)); break;
        case 56: _t->setDateTimeOriginal(*reinterpret_cast< QVariant*>(_v)); break;
        case 57: _t->setDateTimeDigitized(*reinterpret_cast< QVariant*>(_v)); break;
        case 58: _t->setSubjectDistance(*reinterpret_cast< QVariant*>(_v)); break;
        case 59: _t->setMeteringMode(*reinterpret_cast< QVariant*>(_v)); break;
        case 60: _t->setLightSource(*reinterpret_cast< QVariant*>(_v)); break;
        case 61: _t->setFlash(*reinterpret_cast< QVariant*>(_v)); break;
        case 62: _t->setFocalLength(*reinterpret_cast< QVariant*>(_v)); break;
        case 63: _t->setExposureMode(*reinterpret_cast< QVariant*>(_v)); break;
        case 64: _t->setWhiteBalance(*reinterpret_cast< QVariant*>(_v)); break;
        case 65: _t->setDigitalZoomRatio(*reinterpret_cast< QVariant*>(_v)); break;
        case 66: _t->setFocalLengthIn35mmFilm(*reinterpret_cast< QVariant*>(_v)); break;
        case 67: _t->setSceneCaptureType(*reinterpret_cast< QVariant*>(_v)); break;
        case 68: _t->setGainControl(*reinterpret_cast< QVariant*>(_v)); break;
        case 69: _t->setContrast(*reinterpret_cast< QVariant*>(_v)); break;
        case 70: _t->setSaturation(*reinterpret_cast< QVariant*>(_v)); break;
        case 71: _t->setSharpness(*reinterpret_cast< QVariant*>(_v)); break;
        case 72: _t->setDeviceSettingDescription(*reinterpret_cast< QVariant*>(_v)); break;
        case 73: _t->setGPSLatitude(*reinterpret_cast< QVariant*>(_v)); break;
        case 74: _t->setGPSLongitude(*reinterpret_cast< QVariant*>(_v)); break;
        case 75: _t->setGPSAltitude(*reinterpret_cast< QVariant*>(_v)); break;
        case 76: _t->setGPSTimeStamp(*reinterpret_cast< QVariant*>(_v)); break;
        case 77: _t->setGPSSatellites(*reinterpret_cast< QVariant*>(_v)); break;
        case 78: _t->setGPSStatus(*reinterpret_cast< QVariant*>(_v)); break;
        case 79: _t->setGPSDOP(*reinterpret_cast< QVariant*>(_v)); break;
        case 80: _t->setGPSSpeed(*reinterpret_cast< QVariant*>(_v)); break;
        case 81: _t->setGPSTrack(*reinterpret_cast< QVariant*>(_v)); break;
        case 82: _t->setGPSTrackRef(*reinterpret_cast< QVariant*>(_v)); break;
        case 83: _t->setGPSImgDirection(*reinterpret_cast< QVariant*>(_v)); break;
        case 84: _t->setGPSImgDirectionRef(*reinterpret_cast< QVariant*>(_v)); break;
        case 85: _t->setGPSMapDatum(*reinterpret_cast< QVariant*>(_v)); break;
        case 86: _t->setGPSProcessingMethod(*reinterpret_cast< QVariant*>(_v)); break;
        case 87: _t->setGPSAreaInformation(*reinterpret_cast< QVariant*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject QDeclarativeMediaMetaData::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QDeclarativeMediaMetaData.data,
    qt_meta_data_QDeclarativeMediaMetaData,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QDeclarativeMediaMetaData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QDeclarativeMediaMetaData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QDeclarativeMediaMetaData.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QDeclarativeMediaMetaData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 88;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 88;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 88;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 88;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 88;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 88;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QDeclarativeMediaMetaData::metaDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
