/****************************************************************************
** Meta object code from reading C++ file 'qvideowidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/multimediawidgets/qvideowidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qvideowidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QVideoWidget_t {
    QByteArrayData data[32];
    char stringdata0[461];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QVideoWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QVideoWidget_t qt_meta_stringdata_QVideoWidget = {
    {
QT_MOC_LITERAL(0, 0, 12), // "QVideoWidget"
QT_MOC_LITERAL(1, 13, 17), // "fullScreenChanged"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 10), // "fullScreen"
QT_MOC_LITERAL(4, 43, 17), // "brightnessChanged"
QT_MOC_LITERAL(5, 61, 10), // "brightness"
QT_MOC_LITERAL(6, 72, 15), // "contrastChanged"
QT_MOC_LITERAL(7, 88, 8), // "contrast"
QT_MOC_LITERAL(8, 97, 10), // "hueChanged"
QT_MOC_LITERAL(9, 108, 3), // "hue"
QT_MOC_LITERAL(10, 112, 17), // "saturationChanged"
QT_MOC_LITERAL(11, 130, 10), // "saturation"
QT_MOC_LITERAL(12, 141, 13), // "setFullScreen"
QT_MOC_LITERAL(13, 155, 18), // "setAspectRatioMode"
QT_MOC_LITERAL(14, 174, 19), // "Qt::AspectRatioMode"
QT_MOC_LITERAL(15, 194, 4), // "mode"
QT_MOC_LITERAL(16, 199, 13), // "setBrightness"
QT_MOC_LITERAL(17, 213, 11), // "setContrast"
QT_MOC_LITERAL(18, 225, 6), // "setHue"
QT_MOC_LITERAL(19, 232, 13), // "setSaturation"
QT_MOC_LITERAL(20, 246, 19), // "_q_serviceDestroyed"
QT_MOC_LITERAL(21, 266, 20), // "_q_brightnessChanged"
QT_MOC_LITERAL(22, 287, 18), // "_q_contrastChanged"
QT_MOC_LITERAL(23, 306, 13), // "_q_hueChanged"
QT_MOC_LITERAL(24, 320, 20), // "_q_saturationChanged"
QT_MOC_LITERAL(25, 341, 20), // "_q_fullScreenChanged"
QT_MOC_LITERAL(26, 362, 20), // "_q_dimensionsChanged"
QT_MOC_LITERAL(27, 383, 11), // "mediaObject"
QT_MOC_LITERAL(28, 395, 13), // "QMediaObject*"
QT_MOC_LITERAL(29, 409, 15), // "aspectRatioMode"
QT_MOC_LITERAL(30, 425, 12), // "videoSurface"
QT_MOC_LITERAL(31, 438, 22) // "QAbstractVideoSurface*"

    },
    "QVideoWidget\0fullScreenChanged\0\0"
    "fullScreen\0brightnessChanged\0brightness\0"
    "contrastChanged\0contrast\0hueChanged\0"
    "hue\0saturationChanged\0saturation\0"
    "setFullScreen\0setAspectRatioMode\0"
    "Qt::AspectRatioMode\0mode\0setBrightness\0"
    "setContrast\0setHue\0setSaturation\0"
    "_q_serviceDestroyed\0_q_brightnessChanged\0"
    "_q_contrastChanged\0_q_hueChanged\0"
    "_q_saturationChanged\0_q_fullScreenChanged\0"
    "_q_dimensionsChanged\0mediaObject\0"
    "QMediaObject*\0aspectRatioMode\0"
    "videoSurface\0QAbstractVideoSurface*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QVideoWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       8,  154, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  104,    2, 0x06 /* Public */,
       4,    1,  107,    2, 0x06 /* Public */,
       6,    1,  110,    2, 0x06 /* Public */,
       8,    1,  113,    2, 0x06 /* Public */,
      10,    1,  116,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    1,  119,    2, 0x0a /* Public */,
      13,    1,  122,    2, 0x0a /* Public */,
      16,    1,  125,    2, 0x0a /* Public */,
      17,    1,  128,    2, 0x0a /* Public */,
      18,    1,  131,    2, 0x0a /* Public */,
      19,    1,  134,    2, 0x0a /* Public */,
      20,    0,  137,    2, 0x08 /* Private */,
      21,    1,  138,    2, 0x08 /* Private */,
      22,    1,  141,    2, 0x08 /* Private */,
      23,    1,  144,    2, 0x08 /* Private */,
      24,    1,  147,    2, 0x08 /* Private */,
      25,    1,  150,    2, 0x08 /* Private */,
      26,    0,  153,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Int,   11,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,

 // properties: name, type, flags
      27, 0x80000000 | 28, 0x0009510b,
       3, QMetaType::Bool, 0x00495103,
      29, 0x80000000 | 14, 0x0009510b,
       5, QMetaType::Int, 0x00495103,
       7, QMetaType::Int, 0x00495103,
       9, QMetaType::Int, 0x00495103,
      11, QMetaType::Int, 0x00495103,
      30, 0x80000000 | 31, 0x00095409,

 // properties: notify_signal_id
       0,
       0,
       0,
       1,
       2,
       3,
       4,
       0,

       0        // eod
};

void QVideoWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QVideoWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->fullScreenChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->brightnessChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->contrastChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->hueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->saturationChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->setFullScreen((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->setAspectRatioMode((*reinterpret_cast< Qt::AspectRatioMode(*)>(_a[1]))); break;
        case 7: _t->setBrightness((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->setContrast((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->setHue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->setSaturation((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->d_func()->_q_serviceDestroyed(); break;
        case 12: _t->d_func()->_q_brightnessChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->d_func()->_q_contrastChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->d_func()->_q_hueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->d_func()->_q_saturationChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->d_func()->_q_fullScreenChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->d_func()->_q_dimensionsChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QVideoWidget::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QVideoWidget::fullScreenChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QVideoWidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QVideoWidget::brightnessChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QVideoWidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QVideoWidget::contrastChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QVideoWidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QVideoWidget::hueChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QVideoWidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QVideoWidget::saturationChanged)) {
                *result = 4;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QMediaObject* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QVideoWidget *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QMediaObject**>(_v) = _t->mediaObject(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->isFullScreen(); break;
        case 2: *reinterpret_cast< Qt::AspectRatioMode*>(_v) = _t->aspectRatioMode(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->brightness(); break;
        case 4: *reinterpret_cast< int*>(_v) = _t->contrast(); break;
        case 5: *reinterpret_cast< int*>(_v) = _t->hue(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->saturation(); break;
        case 7: *reinterpret_cast< QAbstractVideoSurface**>(_v) = _t->videoSurface(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QVideoWidget *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMediaObject(*reinterpret_cast< QMediaObject**>(_v)); break;
        case 1: _t->setFullScreen(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setAspectRatioMode(*reinterpret_cast< Qt::AspectRatioMode*>(_v)); break;
        case 3: _t->setBrightness(*reinterpret_cast< int*>(_v)); break;
        case 4: _t->setContrast(*reinterpret_cast< int*>(_v)); break;
        case 5: _t->setHue(*reinterpret_cast< int*>(_v)); break;
        case 6: _t->setSaturation(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QVideoWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_QVideoWidget.data,
    qt_meta_data_QVideoWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QVideoWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QVideoWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QVideoWidget.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QMediaBindableInterface"))
        return static_cast< QMediaBindableInterface*>(this);
    if (!strcmp(_clname, "org.qt-project.qt.mediabindable/5.0"))
        return static_cast< QMediaBindableInterface*>(this);
    return QWidget::qt_metacast(_clname);
}

int QVideoWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 18;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QVideoWidget::fullScreenChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QVideoWidget::brightnessChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QVideoWidget::contrastChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QVideoWidget::hueChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QVideoWidget::saturationChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
