/****************************************************************************
** Meta object code from reading C++ file 'qdeclarativeradiodata_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../git/src/imports/multimedia/qdeclarativeradiodata_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qdeclarativeradiodata_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QDeclarativeRadioData_t {
    QByteArrayData data[89];
    char stringdata0[1172];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QDeclarativeRadioData_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QDeclarativeRadioData_t qt_meta_stringdata_QDeclarativeRadioData = {
    {
QT_MOC_LITERAL(0, 0, 21), // "QDeclarativeRadioData"
QT_MOC_LITERAL(1, 22, 16), // "stationIdChanged"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 9), // "stationId"
QT_MOC_LITERAL(4, 50, 18), // "programTypeChanged"
QT_MOC_LITERAL(5, 69, 34), // "QDeclarativeRadioData::Progra..."
QT_MOC_LITERAL(6, 104, 11), // "programType"
QT_MOC_LITERAL(7, 116, 22), // "programTypeNameChanged"
QT_MOC_LITERAL(8, 139, 15), // "programTypeName"
QT_MOC_LITERAL(9, 155, 18), // "stationNameChanged"
QT_MOC_LITERAL(10, 174, 11), // "stationName"
QT_MOC_LITERAL(11, 186, 16), // "radioTextChanged"
QT_MOC_LITERAL(12, 203, 9), // "radioText"
QT_MOC_LITERAL(13, 213, 36), // "alternativeFrequenciesEnabled..."
QT_MOC_LITERAL(14, 250, 7), // "enabled"
QT_MOC_LITERAL(15, 258, 19), // "availabilityChanged"
QT_MOC_LITERAL(16, 278, 12), // "Availability"
QT_MOC_LITERAL(17, 291, 12), // "availability"
QT_MOC_LITERAL(18, 304, 12), // "errorChanged"
QT_MOC_LITERAL(19, 317, 5), // "error"
QT_MOC_LITERAL(20, 323, 28), // "QDeclarativeRadioData::Error"
QT_MOC_LITERAL(21, 352, 9), // "errorCode"
QT_MOC_LITERAL(22, 362, 32), // "setAlternativeFrequenciesEnabled"
QT_MOC_LITERAL(23, 395, 21), // "_q_programTypeChanged"
QT_MOC_LITERAL(24, 417, 23), // "QRadioData::ProgramType"
QT_MOC_LITERAL(25, 441, 8), // "_q_error"
QT_MOC_LITERAL(26, 450, 17), // "QRadioData::Error"
QT_MOC_LITERAL(27, 468, 22), // "_q_availabilityChanged"
QT_MOC_LITERAL(28, 491, 31), // "QMultimedia::AvailabilityStatus"
QT_MOC_LITERAL(29, 523, 11), // "isAvailable"
QT_MOC_LITERAL(30, 535, 29), // "alternativeFrequenciesEnabled"
QT_MOC_LITERAL(31, 565, 5), // "Error"
QT_MOC_LITERAL(32, 571, 7), // "NoError"
QT_MOC_LITERAL(33, 579, 13), // "ResourceError"
QT_MOC_LITERAL(34, 593, 9), // "OpenError"
QT_MOC_LITERAL(35, 603, 15), // "OutOfRangeError"
QT_MOC_LITERAL(36, 619, 11), // "ProgramType"
QT_MOC_LITERAL(37, 631, 9), // "Undefined"
QT_MOC_LITERAL(38, 641, 4), // "News"
QT_MOC_LITERAL(39, 646, 14), // "CurrentAffairs"
QT_MOC_LITERAL(40, 661, 11), // "Information"
QT_MOC_LITERAL(41, 673, 5), // "Sport"
QT_MOC_LITERAL(42, 679, 9), // "Education"
QT_MOC_LITERAL(43, 689, 5), // "Drama"
QT_MOC_LITERAL(44, 695, 7), // "Culture"
QT_MOC_LITERAL(45, 703, 7), // "Science"
QT_MOC_LITERAL(46, 711, 6), // "Varied"
QT_MOC_LITERAL(47, 718, 8), // "PopMusic"
QT_MOC_LITERAL(48, 727, 9), // "RockMusic"
QT_MOC_LITERAL(49, 737, 13), // "EasyListening"
QT_MOC_LITERAL(50, 751, 14), // "LightClassical"
QT_MOC_LITERAL(51, 766, 16), // "SeriousClassical"
QT_MOC_LITERAL(52, 783, 10), // "OtherMusic"
QT_MOC_LITERAL(53, 794, 7), // "Weather"
QT_MOC_LITERAL(54, 802, 7), // "Finance"
QT_MOC_LITERAL(55, 810, 19), // "ChildrensProgrammes"
QT_MOC_LITERAL(56, 830, 13), // "SocialAffairs"
QT_MOC_LITERAL(57, 844, 8), // "Religion"
QT_MOC_LITERAL(58, 853, 7), // "PhoneIn"
QT_MOC_LITERAL(59, 861, 6), // "Travel"
QT_MOC_LITERAL(60, 868, 7), // "Leisure"
QT_MOC_LITERAL(61, 876, 9), // "JazzMusic"
QT_MOC_LITERAL(62, 886, 12), // "CountryMusic"
QT_MOC_LITERAL(63, 899, 13), // "NationalMusic"
QT_MOC_LITERAL(64, 913, 11), // "OldiesMusic"
QT_MOC_LITERAL(65, 925, 9), // "FolkMusic"
QT_MOC_LITERAL(66, 935, 11), // "Documentary"
QT_MOC_LITERAL(67, 947, 9), // "AlarmTest"
QT_MOC_LITERAL(68, 957, 5), // "Alarm"
QT_MOC_LITERAL(69, 963, 4), // "Talk"
QT_MOC_LITERAL(70, 968, 11), // "ClassicRock"
QT_MOC_LITERAL(71, 980, 9), // "AdultHits"
QT_MOC_LITERAL(72, 990, 8), // "SoftRock"
QT_MOC_LITERAL(73, 999, 5), // "Top40"
QT_MOC_LITERAL(74, 1005, 4), // "Soft"
QT_MOC_LITERAL(75, 1010, 9), // "Nostalgia"
QT_MOC_LITERAL(76, 1020, 9), // "Classical"
QT_MOC_LITERAL(77, 1030, 14), // "RhythmAndBlues"
QT_MOC_LITERAL(78, 1045, 18), // "SoftRhythmAndBlues"
QT_MOC_LITERAL(79, 1064, 8), // "Language"
QT_MOC_LITERAL(80, 1073, 14), // "ReligiousMusic"
QT_MOC_LITERAL(81, 1088, 13), // "ReligiousTalk"
QT_MOC_LITERAL(82, 1102, 11), // "Personality"
QT_MOC_LITERAL(83, 1114, 6), // "Public"
QT_MOC_LITERAL(84, 1121, 7), // "College"
QT_MOC_LITERAL(85, 1129, 9), // "Available"
QT_MOC_LITERAL(86, 1139, 4), // "Busy"
QT_MOC_LITERAL(87, 1144, 11), // "Unavailable"
QT_MOC_LITERAL(88, 1156, 15) // "ResourceMissing"

    },
    "QDeclarativeRadioData\0stationIdChanged\0"
    "\0stationId\0programTypeChanged\0"
    "QDeclarativeRadioData::ProgramType\0"
    "programType\0programTypeNameChanged\0"
    "programTypeName\0stationNameChanged\0"
    "stationName\0radioTextChanged\0radioText\0"
    "alternativeFrequenciesEnabledChanged\0"
    "enabled\0availabilityChanged\0Availability\0"
    "availability\0errorChanged\0error\0"
    "QDeclarativeRadioData::Error\0errorCode\0"
    "setAlternativeFrequenciesEnabled\0"
    "_q_programTypeChanged\0QRadioData::ProgramType\0"
    "_q_error\0QRadioData::Error\0"
    "_q_availabilityChanged\0"
    "QMultimedia::AvailabilityStatus\0"
    "isAvailable\0alternativeFrequenciesEnabled\0"
    "Error\0NoError\0ResourceError\0OpenError\0"
    "OutOfRangeError\0ProgramType\0Undefined\0"
    "News\0CurrentAffairs\0Information\0Sport\0"
    "Education\0Drama\0Culture\0Science\0Varied\0"
    "PopMusic\0RockMusic\0EasyListening\0"
    "LightClassical\0SeriousClassical\0"
    "OtherMusic\0Weather\0Finance\0"
    "ChildrensProgrammes\0SocialAffairs\0"
    "Religion\0PhoneIn\0Travel\0Leisure\0"
    "JazzMusic\0CountryMusic\0NationalMusic\0"
    "OldiesMusic\0FolkMusic\0Documentary\0"
    "AlarmTest\0Alarm\0Talk\0ClassicRock\0"
    "AdultHits\0SoftRock\0Top40\0Soft\0Nostalgia\0"
    "Classical\0RhythmAndBlues\0SoftRhythmAndBlues\0"
    "Language\0ReligiousMusic\0ReligiousTalk\0"
    "Personality\0Public\0College\0Available\0"
    "Busy\0Unavailable\0ResourceMissing"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QDeclarativeRadioData[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       7,  122, // properties
       3,  150, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   84,    2, 0x06 /* Public */,
       4,    1,   87,    2, 0x06 /* Public */,
       7,    1,   90,    2, 0x06 /* Public */,
       9,    1,   93,    2, 0x06 /* Public */,
      11,    1,   96,    2, 0x06 /* Public */,
      13,    1,   99,    2, 0x06 /* Public */,
      15,    1,  102,    2, 0x06 /* Public */,
      18,    0,  105,    2, 0x06 /* Public */,
      19,    1,  106,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      22,    1,  109,    2, 0x0a /* Public */,
      23,    1,  112,    2, 0x08 /* Private */,
      25,    1,  115,    2, 0x08 /* Private */,
      27,    1,  118,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      29,    0,  121,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 20,   21,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void, 0x80000000 | 24,    6,
    QMetaType::Void, 0x80000000 | 26,   21,
    QMetaType::Void, 0x80000000 | 28,    2,

 // methods: parameters
    QMetaType::Bool,

 // properties: name, type, flags
       3, QMetaType::QString, 0x00495001,
       6, 0x80000000 | 5, 0x00495009,
       8, QMetaType::QString, 0x00495001,
      10, QMetaType::QString, 0x00495001,
      12, QMetaType::QString, 0x00495001,
      30, QMetaType::Bool, 0x00495103,
      17, 0x80000000 | 16, 0x00495009,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,
       6,

 // enums: name, alias, flags, count, data
      31,   31, 0x0,    4,  165,
      36,   36, 0x0,   48,  173,
      16,   16, 0x0,    4,  269,

 // enum data: key, value
      32, uint(QDeclarativeRadioData::NoError),
      33, uint(QDeclarativeRadioData::ResourceError),
      34, uint(QDeclarativeRadioData::OpenError),
      35, uint(QDeclarativeRadioData::OutOfRangeError),
      37, uint(QDeclarativeRadioData::Undefined),
      38, uint(QDeclarativeRadioData::News),
      39, uint(QDeclarativeRadioData::CurrentAffairs),
      40, uint(QDeclarativeRadioData::Information),
      41, uint(QDeclarativeRadioData::Sport),
      42, uint(QDeclarativeRadioData::Education),
      43, uint(QDeclarativeRadioData::Drama),
      44, uint(QDeclarativeRadioData::Culture),
      45, uint(QDeclarativeRadioData::Science),
      46, uint(QDeclarativeRadioData::Varied),
      47, uint(QDeclarativeRadioData::PopMusic),
      48, uint(QDeclarativeRadioData::RockMusic),
      49, uint(QDeclarativeRadioData::EasyListening),
      50, uint(QDeclarativeRadioData::LightClassical),
      51, uint(QDeclarativeRadioData::SeriousClassical),
      52, uint(QDeclarativeRadioData::OtherMusic),
      53, uint(QDeclarativeRadioData::Weather),
      54, uint(QDeclarativeRadioData::Finance),
      55, uint(QDeclarativeRadioData::ChildrensProgrammes),
      56, uint(QDeclarativeRadioData::SocialAffairs),
      57, uint(QDeclarativeRadioData::Religion),
      58, uint(QDeclarativeRadioData::PhoneIn),
      59, uint(QDeclarativeRadioData::Travel),
      60, uint(QDeclarativeRadioData::Leisure),
      61, uint(QDeclarativeRadioData::JazzMusic),
      62, uint(QDeclarativeRadioData::CountryMusic),
      63, uint(QDeclarativeRadioData::NationalMusic),
      64, uint(QDeclarativeRadioData::OldiesMusic),
      65, uint(QDeclarativeRadioData::FolkMusic),
      66, uint(QDeclarativeRadioData::Documentary),
      67, uint(QDeclarativeRadioData::AlarmTest),
      68, uint(QDeclarativeRadioData::Alarm),
      69, uint(QDeclarativeRadioData::Talk),
      70, uint(QDeclarativeRadioData::ClassicRock),
      71, uint(QDeclarativeRadioData::AdultHits),
      72, uint(QDeclarativeRadioData::SoftRock),
      73, uint(QDeclarativeRadioData::Top40),
      74, uint(QDeclarativeRadioData::Soft),
      75, uint(QDeclarativeRadioData::Nostalgia),
      76, uint(QDeclarativeRadioData::Classical),
      77, uint(QDeclarativeRadioData::RhythmAndBlues),
      78, uint(QDeclarativeRadioData::SoftRhythmAndBlues),
      79, uint(QDeclarativeRadioData::Language),
      80, uint(QDeclarativeRadioData::ReligiousMusic),
      81, uint(QDeclarativeRadioData::ReligiousTalk),
      82, uint(QDeclarativeRadioData::Personality),
      83, uint(QDeclarativeRadioData::Public),
      84, uint(QDeclarativeRadioData::College),
      85, uint(QDeclarativeRadioData::Available),
      86, uint(QDeclarativeRadioData::Busy),
      87, uint(QDeclarativeRadioData::Unavailable),
      88, uint(QDeclarativeRadioData::ResourceMissing),

       0        // eod
};

void QDeclarativeRadioData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QDeclarativeRadioData *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->stationIdChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 1: _t->programTypeChanged((*reinterpret_cast< QDeclarativeRadioData::ProgramType(*)>(_a[1]))); break;
        case 2: _t->programTypeNameChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 3: _t->stationNameChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 4: _t->radioTextChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 5: _t->alternativeFrequenciesEnabledChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->availabilityChanged((*reinterpret_cast< Availability(*)>(_a[1]))); break;
        case 7: _t->errorChanged(); break;
        case 8: _t->error((*reinterpret_cast< QDeclarativeRadioData::Error(*)>(_a[1]))); break;
        case 9: _t->setAlternativeFrequenciesEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->_q_programTypeChanged((*reinterpret_cast< QRadioData::ProgramType(*)>(_a[1]))); break;
        case 11: _t->_q_error((*reinterpret_cast< QRadioData::Error(*)>(_a[1]))); break;
        case 12: _t->_q_availabilityChanged((*reinterpret_cast< QMultimedia::AvailabilityStatus(*)>(_a[1]))); break;
        case 13: { bool _r = _t->isAvailable();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QRadioData::ProgramType >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QRadioData::Error >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QMultimedia::AvailabilityStatus >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QDeclarativeRadioData::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeRadioData::stationIdChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QDeclarativeRadioData::*)(QDeclarativeRadioData::ProgramType );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeRadioData::programTypeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QDeclarativeRadioData::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeRadioData::programTypeNameChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QDeclarativeRadioData::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeRadioData::stationNameChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QDeclarativeRadioData::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeRadioData::radioTextChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QDeclarativeRadioData::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeRadioData::alternativeFrequenciesEnabledChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QDeclarativeRadioData::*)(Availability );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeRadioData::availabilityChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QDeclarativeRadioData::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeRadioData::errorChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QDeclarativeRadioData::*)(QDeclarativeRadioData::Error );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeRadioData::error)) {
                *result = 8;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QDeclarativeRadioData *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->stationId(); break;
        case 1: *reinterpret_cast< QDeclarativeRadioData::ProgramType*>(_v) = _t->programType(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->programTypeName(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->stationName(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->radioText(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->alternativeFrequenciesEnabled(); break;
        case 6: *reinterpret_cast< Availability*>(_v) = _t->availability(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QDeclarativeRadioData *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setAlternativeFrequenciesEnabled(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QDeclarativeRadioData::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QDeclarativeRadioData.data,
    qt_meta_data_QDeclarativeRadioData,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QDeclarativeRadioData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QDeclarativeRadioData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QDeclarativeRadioData.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QDeclarativeRadioData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 7;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QDeclarativeRadioData::stationIdChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QDeclarativeRadioData::programTypeChanged(QDeclarativeRadioData::ProgramType _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QDeclarativeRadioData::programTypeNameChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QDeclarativeRadioData::stationNameChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QDeclarativeRadioData::radioTextChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void QDeclarativeRadioData::alternativeFrequenciesEnabledChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void QDeclarativeRadioData::availabilityChanged(Availability _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void QDeclarativeRadioData::errorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QDeclarativeRadioData::error(QDeclarativeRadioData::Error _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
