/****************************************************************************
** Meta object code from reading C++ file 'qgstreamercapturesession.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../git/src/plugins/gstreamer/mediacapture/qgstreamercapturesession.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qgstreamercapturesession.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QGstreamerCaptureSession_t {
    QByteArrayData data[40];
    char stringdata0[480];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QGstreamerCaptureSession_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QGstreamerCaptureSession_t qt_meta_stringdata_QGstreamerCaptureSession = {
    {
QT_MOC_LITERAL(0, 0, 24), // "QGstreamerCaptureSession"
QT_MOC_LITERAL(1, 25, 12), // "stateChanged"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 31), // "QGstreamerCaptureSession::State"
QT_MOC_LITERAL(4, 71, 5), // "state"
QT_MOC_LITERAL(5, 77, 15), // "durationChanged"
QT_MOC_LITERAL(6, 93, 8), // "duration"
QT_MOC_LITERAL(7, 102, 5), // "error"
QT_MOC_LITERAL(8, 108, 11), // "errorString"
QT_MOC_LITERAL(9, 120, 12), // "imageExposed"
QT_MOC_LITERAL(10, 133, 9), // "requestId"
QT_MOC_LITERAL(11, 143, 13), // "imageCaptured"
QT_MOC_LITERAL(12, 157, 3), // "img"
QT_MOC_LITERAL(13, 161, 10), // "imageSaved"
QT_MOC_LITERAL(14, 172, 4), // "path"
QT_MOC_LITERAL(15, 177, 12), // "mutedChanged"
QT_MOC_LITERAL(16, 190, 13), // "volumeChanged"
QT_MOC_LITERAL(17, 204, 12), // "readyChanged"
QT_MOC_LITERAL(18, 217, 17), // "viewfinderChanged"
QT_MOC_LITERAL(19, 235, 8), // "setState"
QT_MOC_LITERAL(20, 244, 16), // "setCaptureDevice"
QT_MOC_LITERAL(21, 261, 10), // "deviceName"
QT_MOC_LITERAL(22, 272, 9), // "dumpGraph"
QT_MOC_LITERAL(23, 282, 8), // "fileName"
QT_MOC_LITERAL(24, 291, 11), // "setMetaData"
QT_MOC_LITERAL(25, 303, 25), // "QMap<QByteArray,QVariant>"
QT_MOC_LITERAL(26, 329, 8), // "setMuted"
QT_MOC_LITERAL(27, 338, 9), // "setVolume"
QT_MOC_LITERAL(28, 348, 6), // "volume"
QT_MOC_LITERAL(29, 355, 11), // "CaptureMode"
QT_MOC_LITERAL(30, 367, 5), // "Audio"
QT_MOC_LITERAL(31, 373, 5), // "Video"
QT_MOC_LITERAL(32, 379, 5), // "Image"
QT_MOC_LITERAL(33, 385, 13), // "AudioAndVideo"
QT_MOC_LITERAL(34, 399, 21), // "AudioAndVideoAndImage"
QT_MOC_LITERAL(35, 421, 5), // "State"
QT_MOC_LITERAL(36, 427, 12), // "StoppedState"
QT_MOC_LITERAL(37, 440, 12), // "PreviewState"
QT_MOC_LITERAL(38, 453, 11), // "PausedState"
QT_MOC_LITERAL(39, 465, 14) // "RecordingState"

    },
    "QGstreamerCaptureSession\0stateChanged\0"
    "\0QGstreamerCaptureSession::State\0state\0"
    "durationChanged\0duration\0error\0"
    "errorString\0imageExposed\0requestId\0"
    "imageCaptured\0img\0imageSaved\0path\0"
    "mutedChanged\0volumeChanged\0readyChanged\0"
    "viewfinderChanged\0setState\0setCaptureDevice\0"
    "deviceName\0dumpGraph\0fileName\0setMetaData\0"
    "QMap<QByteArray,QVariant>\0setMuted\0"
    "setVolume\0volume\0CaptureMode\0Audio\0"
    "Video\0Image\0AudioAndVideo\0"
    "AudioAndVideoAndImage\0State\0StoppedState\0"
    "PreviewState\0PausedState\0RecordingState"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QGstreamerCaptureSession[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       1,  146, // properties
       2,  150, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   94,    2, 0x06 /* Public */,
       5,    1,   97,    2, 0x06 /* Public */,
       7,    2,  100,    2, 0x06 /* Public */,
       9,    1,  105,    2, 0x06 /* Public */,
      11,    2,  108,    2, 0x06 /* Public */,
      13,    2,  113,    2, 0x06 /* Public */,
      15,    1,  118,    2, 0x06 /* Public */,
      16,    1,  121,    2, 0x06 /* Public */,
      17,    1,  124,    2, 0x06 /* Public */,
      18,    0,  127,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      19,    1,  128,    2, 0x0a /* Public */,
      20,    1,  131,    2, 0x0a /* Public */,
      22,    1,  134,    2, 0x0a /* Public */,
      24,    1,  137,    2, 0x0a /* Public */,
      26,    1,  140,    2, 0x0a /* Public */,
      27,    1,  143,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::LongLong,    6,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    7,    8,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::Int, QMetaType::QImage,   10,   12,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   10,   14,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QReal,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, QMetaType::QString,   21,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void, 0x80000000 | 25,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QReal,   28,

 // properties: name, type, flags
       6, QMetaType::LongLong, 0x00495001,

 // properties: notify_signal_id
       1,

 // enums: name, alias, flags, count, data
      29,   29, 0x0,    5,  160,
      35,   35, 0x0,    4,  170,

 // enum data: key, value
      30, uint(QGstreamerCaptureSession::Audio),
      31, uint(QGstreamerCaptureSession::Video),
      32, uint(QGstreamerCaptureSession::Image),
      33, uint(QGstreamerCaptureSession::AudioAndVideo),
      34, uint(QGstreamerCaptureSession::AudioAndVideoAndImage),
      36, uint(QGstreamerCaptureSession::StoppedState),
      37, uint(QGstreamerCaptureSession::PreviewState),
      38, uint(QGstreamerCaptureSession::PausedState),
      39, uint(QGstreamerCaptureSession::RecordingState),

       0        // eod
};

void QGstreamerCaptureSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QGstreamerCaptureSession *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->stateChanged((*reinterpret_cast< QGstreamerCaptureSession::State(*)>(_a[1]))); break;
        case 1: _t->durationChanged((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 2: _t->error((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->imageExposed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->imageCaptured((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QImage(*)>(_a[2]))); break;
        case 5: _t->imageSaved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 6: _t->mutedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->volumeChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 8: _t->readyChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->viewfinderChanged(); break;
        case 10: _t->setState((*reinterpret_cast< QGstreamerCaptureSession::State(*)>(_a[1]))); break;
        case 11: _t->setCaptureDevice((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->dumpGraph((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->setMetaData((*reinterpret_cast< const QMap<QByteArray,QVariant>(*)>(_a[1]))); break;
        case 14: _t->setMuted((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->setVolume((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QGstreamerCaptureSession::*)(QGstreamerCaptureSession::State );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerCaptureSession::stateChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QGstreamerCaptureSession::*)(qint64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerCaptureSession::durationChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QGstreamerCaptureSession::*)(int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerCaptureSession::error)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QGstreamerCaptureSession::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerCaptureSession::imageExposed)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QGstreamerCaptureSession::*)(int , const QImage & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerCaptureSession::imageCaptured)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QGstreamerCaptureSession::*)(int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerCaptureSession::imageSaved)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QGstreamerCaptureSession::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerCaptureSession::mutedChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QGstreamerCaptureSession::*)(qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerCaptureSession::volumeChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QGstreamerCaptureSession::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerCaptureSession::readyChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (QGstreamerCaptureSession::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QGstreamerCaptureSession::viewfinderChanged)) {
                *result = 9;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QGstreamerCaptureSession *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qint64*>(_v) = _t->duration(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QGstreamerCaptureSession::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QGstreamerCaptureSession.data,
    qt_meta_data_QGstreamerCaptureSession,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QGstreamerCaptureSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QGstreamerCaptureSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QGstreamerCaptureSession.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QGstreamerBusMessageFilter"))
        return static_cast< QGstreamerBusMessageFilter*>(this);
    if (!strcmp(_clname, "org.qt-project.qt.gstreamerbusmessagefilter/5.0"))
        return static_cast< QGstreamerBusMessageFilter*>(this);
    return QObject::qt_metacast(_clname);
}

int QGstreamerCaptureSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QGstreamerCaptureSession::stateChanged(QGstreamerCaptureSession::State _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QGstreamerCaptureSession::durationChanged(qint64 _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QGstreamerCaptureSession::error(int _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QGstreamerCaptureSession::imageExposed(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QGstreamerCaptureSession::imageCaptured(int _t1, const QImage & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void QGstreamerCaptureSession::imageSaved(int _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void QGstreamerCaptureSession::mutedChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void QGstreamerCaptureSession::volumeChanged(qreal _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void QGstreamerCaptureSession::readyChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void QGstreamerCaptureSession::viewfinderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
