/****************************************************************************
** Meta object code from reading C++ file 'qdeclarativecameracapture_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../git/src/imports/multimedia/qdeclarativecameracapture_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qdeclarativecameracapture_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QDeclarativeCameraCapture_t {
    QByteArrayData data[35];
    char stringdata0[502];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QDeclarativeCameraCapture_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QDeclarativeCameraCapture_t qt_meta_stringdata_QDeclarativeCameraCapture = {
    {
QT_MOC_LITERAL(0, 0, 25), // "QDeclarativeCameraCapture"
QT_MOC_LITERAL(1, 26, 22), // "readyForCaptureChanged"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 12), // "imageExposed"
QT_MOC_LITERAL(4, 63, 9), // "requestId"
QT_MOC_LITERAL(5, 73, 13), // "imageCaptured"
QT_MOC_LITERAL(6, 87, 7), // "preview"
QT_MOC_LITERAL(7, 95, 22), // "imageMetadataAvailable"
QT_MOC_LITERAL(8, 118, 3), // "key"
QT_MOC_LITERAL(9, 122, 5), // "value"
QT_MOC_LITERAL(10, 128, 10), // "imageSaved"
QT_MOC_LITERAL(11, 139, 4), // "path"
QT_MOC_LITERAL(12, 144, 13), // "captureFailed"
QT_MOC_LITERAL(13, 158, 7), // "message"
QT_MOC_LITERAL(14, 166, 17), // "resolutionChanged"
QT_MOC_LITERAL(15, 184, 27), // "supportedResolutionsChanged"
QT_MOC_LITERAL(16, 212, 7), // "capture"
QT_MOC_LITERAL(17, 220, 17), // "captureToLocation"
QT_MOC_LITERAL(18, 238, 8), // "location"
QT_MOC_LITERAL(19, 247, 13), // "cancelCapture"
QT_MOC_LITERAL(20, 261, 13), // "setResolution"
QT_MOC_LITERAL(21, 275, 10), // "resolution"
QT_MOC_LITERAL(22, 286, 11), // "setMetadata"
QT_MOC_LITERAL(23, 298, 16), // "_q_imageCaptured"
QT_MOC_LITERAL(24, 315, 13), // "_q_imageSaved"
QT_MOC_LITERAL(25, 329, 25), // "_q_imageMetadataAvailable"
QT_MOC_LITERAL(26, 355, 16), // "_q_captureFailed"
QT_MOC_LITERAL(27, 372, 26), // "QCameraImageCapture::Error"
QT_MOC_LITERAL(28, 399, 22), // "_q_cameraStatusChanged"
QT_MOC_LITERAL(29, 422, 15), // "QCamera::Status"
QT_MOC_LITERAL(30, 438, 6), // "status"
QT_MOC_LITERAL(31, 445, 5), // "ready"
QT_MOC_LITERAL(32, 451, 17), // "capturedImagePath"
QT_MOC_LITERAL(33, 469, 11), // "errorString"
QT_MOC_LITERAL(34, 481, 20) // "supportedResolutions"

    },
    "QDeclarativeCameraCapture\0"
    "readyForCaptureChanged\0\0imageExposed\0"
    "requestId\0imageCaptured\0preview\0"
    "imageMetadataAvailable\0key\0value\0"
    "imageSaved\0path\0captureFailed\0message\0"
    "resolutionChanged\0supportedResolutionsChanged\0"
    "capture\0captureToLocation\0location\0"
    "cancelCapture\0setResolution\0resolution\0"
    "setMetadata\0_q_imageCaptured\0_q_imageSaved\0"
    "_q_imageMetadataAvailable\0_q_captureFailed\0"
    "QCameraImageCapture::Error\0"
    "_q_cameraStatusChanged\0QCamera::Status\0"
    "status\0ready\0capturedImagePath\0"
    "errorString\0supportedResolutions"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QDeclarativeCameraCapture[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
       5,  176, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  104,    2, 0x06 /* Public */,
       3,    1,  107,    2, 0x06 /* Public */,
       5,    2,  110,    2, 0x06 /* Public */,
       7,    3,  115,    2, 0x06 /* Public */,
      10,    2,  122,    2, 0x06 /* Public */,
      12,    2,  127,    2, 0x06 /* Public */,
      14,    1,  132,    2, 0x06 /* Public */,
      15,    0,  135,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    0,  136,    2, 0x0a /* Public */,
      17,    1,  137,    2, 0x0a /* Public */,
      19,    0,  140,    2, 0x0a /* Public */,
      20,    1,  141,    2, 0x0a /* Public */,
      22,    2,  144,    2, 0x0a /* Public */,
      23,    2,  149,    2, 0x08 /* Private */,
      24,    2,  154,    2, 0x08 /* Private */,
      25,    3,  159,    2, 0x08 /* Private */,
      26,    3,  166,    2, 0x08 /* Private */,
      28,    1,  173,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    4,    6,
    QMetaType::Void, QMetaType::Int, QMetaType::QString, QMetaType::QVariant,    4,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    4,   11,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    4,   13,
    QMetaType::Void, QMetaType::QSize,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Int,
    QMetaType::Int, QMetaType::QString,   18,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QSize,   21,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::QImage,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::QString, QMetaType::QVariant,    2,    2,    2,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 27, QMetaType::QString,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 29,   30,

 // properties: name, type, flags
      31, QMetaType::Bool, 0x00495001,
      32, QMetaType::QString, 0x00495001,
      21, QMetaType::QSize, 0x00495103,
      33, QMetaType::QString, 0x00495001,
      34, QMetaType::QVariantList, 0x00c95001,

 // properties: notify_signal_id
       0,
       4,
       6,
       5,
       7,

 // properties: revision
       0,
       0,
       0,
       0,
       1,

       0        // eod
};

void QDeclarativeCameraCapture::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QDeclarativeCameraCapture *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->readyForCaptureChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->imageExposed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->imageCaptured((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->imageMetadataAvailable((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QVariant(*)>(_a[3]))); break;
        case 4: _t->imageSaved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 5: _t->captureFailed((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 6: _t->resolutionChanged((*reinterpret_cast< const QSize(*)>(_a[1]))); break;
        case 7: _t->supportedResolutionsChanged(); break;
        case 8: { int _r = _t->capture();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->captureToLocation((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->cancelCapture(); break;
        case 11: _t->setResolution((*reinterpret_cast< const QSize(*)>(_a[1]))); break;
        case 12: _t->setMetadata((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 13: _t->_q_imageCaptured((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QImage(*)>(_a[2]))); break;
        case 14: _t->_q_imageSaved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 15: _t->_q_imageMetadataAvailable((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QVariant(*)>(_a[3]))); break;
        case 16: _t->_q_captureFailed((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QCameraImageCapture::Error(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 17: _t->_q_cameraStatusChanged((*reinterpret_cast< QCamera::Status(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QCameraImageCapture::Error >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QCamera::Status >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QDeclarativeCameraCapture::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCameraCapture::readyForCaptureChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCameraCapture::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCameraCapture::imageExposed)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCameraCapture::*)(int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCameraCapture::imageCaptured)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCameraCapture::*)(int , const QString & , const QVariant & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCameraCapture::imageMetadataAvailable)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCameraCapture::*)(int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCameraCapture::imageSaved)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCameraCapture::*)(int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCameraCapture::captureFailed)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCameraCapture::*)(const QSize & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCameraCapture::resolutionChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCameraCapture::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCameraCapture::supportedResolutionsChanged)) {
                *result = 7;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QDeclarativeCameraCapture *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isReadyForCapture(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->capturedImagePath(); break;
        case 2: *reinterpret_cast< QSize*>(_v) = _t->resolution(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->errorString(); break;
        case 4: *reinterpret_cast< QVariantList*>(_v) = _t->supportedResolutions(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QDeclarativeCameraCapture *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setResolution(*reinterpret_cast< QSize*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QDeclarativeCameraCapture::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QDeclarativeCameraCapture.data,
    qt_meta_data_QDeclarativeCameraCapture,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QDeclarativeCameraCapture::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QDeclarativeCameraCapture::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QDeclarativeCameraCapture.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QDeclarativeCameraCapture::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 5;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QDeclarativeCameraCapture::readyForCaptureChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QDeclarativeCameraCapture::imageExposed(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QDeclarativeCameraCapture::imageCaptured(int _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QDeclarativeCameraCapture::imageMetadataAvailable(int _t1, const QString & _t2, const QVariant & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QDeclarativeCameraCapture::imageSaved(int _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void QDeclarativeCameraCapture::captureFailed(int _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void QDeclarativeCameraCapture::resolutionChanged(const QSize & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void QDeclarativeCameraCapture::supportedResolutionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
