/****************************************************************************
** Meta object code from reading C++ file 'camerabinfocus.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../git/src/plugins/gstreamer/camerabin/camerabinfocus.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'camerabinfocus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CameraBinFocus_t {
    QByteArrayData data[14];
    char stringdata0[228];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CameraBinFocus_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CameraBinFocus_t qt_meta_stringdata_CameraBinFocus = {
    {
QT_MOC_LITERAL(0, 0, 14), // "CameraBinFocus"
QT_MOC_LITERAL(1, 15, 21), // "_q_focusStatusChanged"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 19), // "QCamera::LockStatus"
QT_MOC_LITERAL(4, 58, 6), // "status"
QT_MOC_LITERAL(5, 65, 25), // "QCamera::LockChangeReason"
QT_MOC_LITERAL(6, 91, 6), // "reason"
QT_MOC_LITERAL(7, 98, 16), // "_q_startFocusing"
QT_MOC_LITERAL(8, 115, 15), // "_q_stopFocusing"
QT_MOC_LITERAL(9, 131, 23), // "setViewfinderResolution"
QT_MOC_LITERAL(10, 155, 10), // "resolution"
QT_MOC_LITERAL(11, 166, 17), // "_q_setFocusStatus"
QT_MOC_LITERAL(12, 184, 27), // "_q_handleCameraStatusChange"
QT_MOC_LITERAL(13, 212, 15) // "QCamera::Status"

    },
    "CameraBinFocus\0_q_focusStatusChanged\0"
    "\0QCamera::LockStatus\0status\0"
    "QCamera::LockChangeReason\0reason\0"
    "_q_startFocusing\0_q_stopFocusing\0"
    "setViewfinderResolution\0resolution\0"
    "_q_setFocusStatus\0_q_handleCameraStatusChange\0"
    "QCamera::Status"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CameraBinFocus[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   44,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   49,    2, 0x0a /* Public */,
       8,    0,   50,    2, 0x0a /* Public */,
       9,    1,   51,    2, 0x0a /* Public */,
      11,    2,   54,    2, 0x08 /* Private */,
      12,    1,   59,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QSize,   10,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 13,    4,

       0        // eod
};

void CameraBinFocus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CameraBinFocus *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->_q_focusStatusChanged((*reinterpret_cast< QCamera::LockStatus(*)>(_a[1])),(*reinterpret_cast< QCamera::LockChangeReason(*)>(_a[2]))); break;
        case 1: _t->_q_startFocusing(); break;
        case 2: _t->_q_stopFocusing(); break;
        case 3: _t->setViewfinderResolution((*reinterpret_cast< const QSize(*)>(_a[1]))); break;
        case 4: _t->_q_setFocusStatus((*reinterpret_cast< QCamera::LockStatus(*)>(_a[1])),(*reinterpret_cast< QCamera::LockChangeReason(*)>(_a[2]))); break;
        case 5: _t->_q_handleCameraStatusChange((*reinterpret_cast< QCamera::Status(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QCamera::LockChangeReason >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QCamera::LockStatus >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QCamera::LockChangeReason >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QCamera::LockStatus >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QCamera::Status >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (CameraBinFocus::*)(QCamera::LockStatus , QCamera::LockChangeReason );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CameraBinFocus::_q_focusStatusChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CameraBinFocus::staticMetaObject = { {
    QMetaObject::SuperData::link<QCameraFocusControl::staticMetaObject>(),
    qt_meta_stringdata_CameraBinFocus.data,
    qt_meta_data_CameraBinFocus,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CameraBinFocus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CameraBinFocus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CameraBinFocus.stringdata0))
        return static_cast<void*>(this);
    return QCameraFocusControl::qt_metacast(_clname);
}

int CameraBinFocus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QCameraFocusControl::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void CameraBinFocus::_q_focusStatusChanged(QCamera::LockStatus _t1, QCamera::LockChangeReason _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
