/****************************************************************************
** Meta object code from reading C++ file 'qcameraimagecapturecontrol.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/multimedia/controls/qcameraimagecapturecontrol.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qcameraimagecapturecontrol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QCameraImageCaptureControl_t {
    QByteArrayData data[19];
    char stringdata0[210];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QCameraImageCaptureControl_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QCameraImageCaptureControl_t qt_meta_stringdata_QCameraImageCaptureControl = {
    {
QT_MOC_LITERAL(0, 0, 26), // "QCameraImageCaptureControl"
QT_MOC_LITERAL(1, 27, 22), // "readyForCaptureChanged"
QT_MOC_LITERAL(2, 50, 0), // ""
QT_MOC_LITERAL(3, 51, 5), // "ready"
QT_MOC_LITERAL(4, 57, 12), // "imageExposed"
QT_MOC_LITERAL(5, 70, 9), // "requestId"
QT_MOC_LITERAL(6, 80, 13), // "imageCaptured"
QT_MOC_LITERAL(7, 94, 7), // "preview"
QT_MOC_LITERAL(8, 102, 22), // "imageMetadataAvailable"
QT_MOC_LITERAL(9, 125, 2), // "id"
QT_MOC_LITERAL(10, 128, 3), // "key"
QT_MOC_LITERAL(11, 132, 5), // "value"
QT_MOC_LITERAL(12, 138, 14), // "imageAvailable"
QT_MOC_LITERAL(13, 153, 11), // "QVideoFrame"
QT_MOC_LITERAL(14, 165, 6), // "buffer"
QT_MOC_LITERAL(15, 172, 10), // "imageSaved"
QT_MOC_LITERAL(16, 183, 8), // "fileName"
QT_MOC_LITERAL(17, 192, 5), // "error"
QT_MOC_LITERAL(18, 198, 11) // "errorString"

    },
    "QCameraImageCaptureControl\0"
    "readyForCaptureChanged\0\0ready\0"
    "imageExposed\0requestId\0imageCaptured\0"
    "preview\0imageMetadataAvailable\0id\0key\0"
    "value\0imageAvailable\0QVideoFrame\0"
    "buffer\0imageSaved\0fileName\0error\0"
    "errorString"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QCameraImageCaptureControl[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,
       4,    1,   52,    2, 0x06 /* Public */,
       6,    2,   55,    2, 0x06 /* Public */,
       8,    3,   60,    2, 0x06 /* Public */,
      12,    2,   67,    2, 0x06 /* Public */,
      15,    2,   72,    2, 0x06 /* Public */,
      17,    3,   77,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int, QMetaType::QImage,    5,    7,
    QMetaType::Void, QMetaType::Int, QMetaType::QString, QMetaType::QVariant,    9,   10,   11,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 13,    5,   14,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    5,   16,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QString,    9,   17,   18,

       0        // eod
};

void QCameraImageCaptureControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QCameraImageCaptureControl *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->readyForCaptureChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->imageExposed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->imageCaptured((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QImage(*)>(_a[2]))); break;
        case 3: _t->imageMetadataAvailable((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QVariant(*)>(_a[3]))); break;
        case 4: _t->imageAvailable((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QVideoFrame(*)>(_a[2]))); break;
        case 5: _t->imageSaved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 6: _t->error((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QVideoFrame >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QCameraImageCaptureControl::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCameraImageCaptureControl::readyForCaptureChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QCameraImageCaptureControl::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCameraImageCaptureControl::imageExposed)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QCameraImageCaptureControl::*)(int , const QImage & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCameraImageCaptureControl::imageCaptured)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QCameraImageCaptureControl::*)(int , const QString & , const QVariant & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCameraImageCaptureControl::imageMetadataAvailable)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QCameraImageCaptureControl::*)(int , const QVideoFrame & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCameraImageCaptureControl::imageAvailable)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QCameraImageCaptureControl::*)(int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCameraImageCaptureControl::imageSaved)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QCameraImageCaptureControl::*)(int , int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCameraImageCaptureControl::error)) {
                *result = 6;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QCameraImageCaptureControl::staticMetaObject = { {
    QMetaObject::SuperData::link<QMediaControl::staticMetaObject>(),
    qt_meta_stringdata_QCameraImageCaptureControl.data,
    qt_meta_data_QCameraImageCaptureControl,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QCameraImageCaptureControl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QCameraImageCaptureControl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QCameraImageCaptureControl.stringdata0))
        return static_cast<void*>(this);
    return QMediaControl::qt_metacast(_clname);
}

int QCameraImageCaptureControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMediaControl::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void QCameraImageCaptureControl::readyForCaptureChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QCameraImageCaptureControl::imageExposed(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QCameraImageCaptureControl::imageCaptured(int _t1, const QImage & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QCameraImageCaptureControl::imageMetadataAvailable(int _t1, const QString & _t2, const QVariant & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QCameraImageCaptureControl::imageAvailable(int _t1, const QVideoFrame & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void QCameraImageCaptureControl::imageSaved(int _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void QCameraImageCaptureControl::error(int _t1, int _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
