/****************************************************************************
** Meta object code from reading C++ file 'qdeclarativecamera_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../git/src/imports/multimedia/qdeclarativecamera_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qdeclarativecamera_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QDeclarativeCamera_t {
    QByteArrayData data[166];
    char stringdata0[2551];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QDeclarativeCamera_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QDeclarativeCamera_t qt_meta_stringdata_QDeclarativeCamera = {
    {
QT_MOC_LITERAL(0, 0, 18), // "QDeclarativeCamera"
QT_MOC_LITERAL(1, 19, 12), // "errorChanged"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 5), // "error"
QT_MOC_LITERAL(4, 39, 25), // "QDeclarativeCamera::Error"
QT_MOC_LITERAL(5, 65, 9), // "errorCode"
QT_MOC_LITERAL(6, 75, 11), // "errorString"
QT_MOC_LITERAL(7, 87, 13), // "errorOccurred"
QT_MOC_LITERAL(8, 101, 15), // "deviceIdChanged"
QT_MOC_LITERAL(9, 117, 15), // "positionChanged"
QT_MOC_LITERAL(10, 133, 18), // "displayNameChanged"
QT_MOC_LITERAL(11, 152, 18), // "orientationChanged"
QT_MOC_LITERAL(12, 171, 18), // "captureModeChanged"
QT_MOC_LITERAL(13, 190, 18), // "cameraStateChanged"
QT_MOC_LITERAL(14, 209, 25), // "QDeclarativeCamera::State"
QT_MOC_LITERAL(15, 235, 19), // "cameraStatusChanged"
QT_MOC_LITERAL(16, 255, 17), // "lockStatusChanged"
QT_MOC_LITERAL(17, 273, 18), // "opticalZoomChanged"
QT_MOC_LITERAL(18, 292, 18), // "digitalZoomChanged"
QT_MOC_LITERAL(19, 311, 25), // "maximumOpticalZoomChanged"
QT_MOC_LITERAL(20, 337, 25), // "maximumDigitalZoomChanged"
QT_MOC_LITERAL(21, 363, 18), // "mediaObjectChanged"
QT_MOC_LITERAL(22, 382, 19), // "availabilityChanged"
QT_MOC_LITERAL(23, 402, 12), // "Availability"
QT_MOC_LITERAL(24, 415, 12), // "availability"
QT_MOC_LITERAL(25, 428, 14), // "setCaptureMode"
QT_MOC_LITERAL(26, 443, 11), // "CaptureMode"
QT_MOC_LITERAL(27, 455, 4), // "mode"
QT_MOC_LITERAL(28, 460, 5), // "start"
QT_MOC_LITERAL(29, 466, 4), // "stop"
QT_MOC_LITERAL(30, 471, 14), // "setCameraState"
QT_MOC_LITERAL(31, 486, 5), // "State"
QT_MOC_LITERAL(32, 492, 5), // "state"
QT_MOC_LITERAL(33, 498, 13), // "searchAndLock"
QT_MOC_LITERAL(34, 512, 6), // "unlock"
QT_MOC_LITERAL(35, 519, 14), // "setOpticalZoom"
QT_MOC_LITERAL(36, 534, 14), // "setDigitalZoom"
QT_MOC_LITERAL(37, 549, 30), // "supportedViewfinderResolutions"
QT_MOC_LITERAL(38, 580, 8), // "QJSValue"
QT_MOC_LITERAL(39, 589, 16), // "minimumFrameRate"
QT_MOC_LITERAL(40, 606, 16), // "maximumFrameRate"
QT_MOC_LITERAL(41, 623, 34), // "supportedViewfinderFrameRateR..."
QT_MOC_LITERAL(42, 658, 10), // "resolution"
QT_MOC_LITERAL(43, 669, 14), // "_q_updateState"
QT_MOC_LITERAL(44, 684, 14), // "QCamera::State"
QT_MOC_LITERAL(45, 699, 16), // "_q_errorOccurred"
QT_MOC_LITERAL(46, 716, 14), // "QCamera::Error"
QT_MOC_LITERAL(47, 731, 22), // "_q_availabilityChanged"
QT_MOC_LITERAL(48, 754, 31), // "QMultimedia::AvailabilityStatus"
QT_MOC_LITERAL(49, 786, 8), // "deviceId"
QT_MOC_LITERAL(50, 795, 8), // "position"
QT_MOC_LITERAL(51, 804, 8), // "Position"
QT_MOC_LITERAL(52, 813, 11), // "displayName"
QT_MOC_LITERAL(53, 825, 11), // "orientation"
QT_MOC_LITERAL(54, 837, 11), // "captureMode"
QT_MOC_LITERAL(55, 849, 11), // "cameraState"
QT_MOC_LITERAL(56, 861, 12), // "cameraStatus"
QT_MOC_LITERAL(57, 874, 6), // "Status"
QT_MOC_LITERAL(58, 881, 10), // "lockStatus"
QT_MOC_LITERAL(59, 892, 10), // "LockStatus"
QT_MOC_LITERAL(60, 903, 5), // "Error"
QT_MOC_LITERAL(61, 909, 11), // "opticalZoom"
QT_MOC_LITERAL(62, 921, 18), // "maximumOpticalZoom"
QT_MOC_LITERAL(63, 940, 11), // "digitalZoom"
QT_MOC_LITERAL(64, 952, 18), // "maximumDigitalZoom"
QT_MOC_LITERAL(65, 971, 11), // "mediaObject"
QT_MOC_LITERAL(66, 983, 12), // "imageCapture"
QT_MOC_LITERAL(67, 996, 26), // "QDeclarativeCameraCapture*"
QT_MOC_LITERAL(68, 1023, 13), // "videoRecorder"
QT_MOC_LITERAL(69, 1037, 27), // "QDeclarativeCameraRecorder*"
QT_MOC_LITERAL(70, 1065, 8), // "exposure"
QT_MOC_LITERAL(71, 1074, 27), // "QDeclarativeCameraExposure*"
QT_MOC_LITERAL(72, 1102, 5), // "flash"
QT_MOC_LITERAL(73, 1108, 24), // "QDeclarativeCameraFlash*"
QT_MOC_LITERAL(74, 1133, 5), // "focus"
QT_MOC_LITERAL(75, 1139, 24), // "QDeclarativeCameraFocus*"
QT_MOC_LITERAL(76, 1164, 15), // "imageProcessing"
QT_MOC_LITERAL(77, 1180, 34), // "QDeclarativeCameraImageProces..."
QT_MOC_LITERAL(78, 1215, 8), // "metaData"
QT_MOC_LITERAL(79, 1224, 26), // "QDeclarativeMediaMetaData*"
QT_MOC_LITERAL(80, 1251, 10), // "viewfinder"
QT_MOC_LITERAL(81, 1262, 29), // "QDeclarativeCameraViewfinder*"
QT_MOC_LITERAL(82, 1292, 19), // "UnspecifiedPosition"
QT_MOC_LITERAL(83, 1312, 8), // "BackFace"
QT_MOC_LITERAL(84, 1321, 9), // "FrontFace"
QT_MOC_LITERAL(85, 1331, 17), // "CaptureViewfinder"
QT_MOC_LITERAL(86, 1349, 17), // "CaptureStillImage"
QT_MOC_LITERAL(87, 1367, 12), // "CaptureVideo"
QT_MOC_LITERAL(88, 1380, 11), // "ActiveState"
QT_MOC_LITERAL(89, 1392, 11), // "LoadedState"
QT_MOC_LITERAL(90, 1404, 13), // "UnloadedState"
QT_MOC_LITERAL(91, 1418, 17), // "UnavailableStatus"
QT_MOC_LITERAL(92, 1436, 14), // "UnloadedStatus"
QT_MOC_LITERAL(93, 1451, 13), // "LoadingStatus"
QT_MOC_LITERAL(94, 1465, 15), // "UnloadingStatus"
QT_MOC_LITERAL(95, 1481, 12), // "LoadedStatus"
QT_MOC_LITERAL(96, 1494, 13), // "StandbyStatus"
QT_MOC_LITERAL(97, 1508, 14), // "StartingStatus"
QT_MOC_LITERAL(98, 1523, 14), // "StoppingStatus"
QT_MOC_LITERAL(99, 1538, 12), // "ActiveStatus"
QT_MOC_LITERAL(100, 1551, 8), // "Unlocked"
QT_MOC_LITERAL(101, 1560, 9), // "Searching"
QT_MOC_LITERAL(102, 1570, 6), // "Locked"
QT_MOC_LITERAL(103, 1577, 7), // "NoError"
QT_MOC_LITERAL(104, 1585, 11), // "CameraError"
QT_MOC_LITERAL(105, 1597, 19), // "InvalidRequestError"
QT_MOC_LITERAL(106, 1617, 19), // "ServiceMissingError"
QT_MOC_LITERAL(107, 1637, 24), // "NotSupportedFeatureError"
QT_MOC_LITERAL(108, 1662, 9), // "FlashMode"
QT_MOC_LITERAL(109, 1672, 9), // "FlashAuto"
QT_MOC_LITERAL(110, 1682, 8), // "FlashOff"
QT_MOC_LITERAL(111, 1691, 7), // "FlashOn"
QT_MOC_LITERAL(112, 1699, 20), // "FlashRedEyeReduction"
QT_MOC_LITERAL(113, 1720, 9), // "FlashFill"
QT_MOC_LITERAL(114, 1730, 10), // "FlashTorch"
QT_MOC_LITERAL(115, 1741, 15), // "FlashVideoLight"
QT_MOC_LITERAL(116, 1757, 25), // "FlashSlowSyncFrontCurtain"
QT_MOC_LITERAL(117, 1783, 24), // "FlashSlowSyncRearCurtain"
QT_MOC_LITERAL(118, 1808, 11), // "FlashManual"
QT_MOC_LITERAL(119, 1820, 12), // "ExposureMode"
QT_MOC_LITERAL(120, 1833, 12), // "ExposureAuto"
QT_MOC_LITERAL(121, 1846, 14), // "ExposureManual"
QT_MOC_LITERAL(122, 1861, 16), // "ExposurePortrait"
QT_MOC_LITERAL(123, 1878, 13), // "ExposureNight"
QT_MOC_LITERAL(124, 1892, 17), // "ExposureBacklight"
QT_MOC_LITERAL(125, 1910, 17), // "ExposureSpotlight"
QT_MOC_LITERAL(126, 1928, 14), // "ExposureSports"
QT_MOC_LITERAL(127, 1943, 12), // "ExposureSnow"
QT_MOC_LITERAL(128, 1956, 13), // "ExposureBeach"
QT_MOC_LITERAL(129, 1970, 21), // "ExposureLargeAperture"
QT_MOC_LITERAL(130, 1992, 21), // "ExposureSmallAperture"
QT_MOC_LITERAL(131, 2014, 14), // "ExposureAction"
QT_MOC_LITERAL(132, 2029, 17), // "ExposureLandscape"
QT_MOC_LITERAL(133, 2047, 21), // "ExposureNightPortrait"
QT_MOC_LITERAL(134, 2069, 15), // "ExposureTheatre"
QT_MOC_LITERAL(135, 2085, 14), // "ExposureSunset"
QT_MOC_LITERAL(136, 2100, 19), // "ExposureSteadyPhoto"
QT_MOC_LITERAL(137, 2120, 17), // "ExposureFireworks"
QT_MOC_LITERAL(138, 2138, 13), // "ExposureParty"
QT_MOC_LITERAL(139, 2152, 19), // "ExposureCandlelight"
QT_MOC_LITERAL(140, 2172, 15), // "ExposureBarcode"
QT_MOC_LITERAL(141, 2188, 18), // "ExposureModeVendor"
QT_MOC_LITERAL(142, 2207, 12), // "MeteringMode"
QT_MOC_LITERAL(143, 2220, 14), // "MeteringMatrix"
QT_MOC_LITERAL(144, 2235, 15), // "MeteringAverage"
QT_MOC_LITERAL(145, 2251, 12), // "MeteringSpot"
QT_MOC_LITERAL(146, 2264, 9), // "FocusMode"
QT_MOC_LITERAL(147, 2274, 11), // "FocusManual"
QT_MOC_LITERAL(148, 2286, 15), // "FocusHyperfocal"
QT_MOC_LITERAL(149, 2302, 13), // "FocusInfinity"
QT_MOC_LITERAL(150, 2316, 9), // "FocusAuto"
QT_MOC_LITERAL(151, 2326, 15), // "FocusContinuous"
QT_MOC_LITERAL(152, 2342, 10), // "FocusMacro"
QT_MOC_LITERAL(153, 2353, 14), // "FocusPointMode"
QT_MOC_LITERAL(154, 2368, 14), // "FocusPointAuto"
QT_MOC_LITERAL(155, 2383, 16), // "FocusPointCenter"
QT_MOC_LITERAL(156, 2400, 23), // "FocusPointFaceDetection"
QT_MOC_LITERAL(157, 2424, 16), // "FocusPointCustom"
QT_MOC_LITERAL(158, 2441, 15), // "FocusAreaStatus"
QT_MOC_LITERAL(159, 2457, 15), // "FocusAreaUnused"
QT_MOC_LITERAL(160, 2473, 17), // "FocusAreaSelected"
QT_MOC_LITERAL(161, 2491, 16), // "FocusAreaFocused"
QT_MOC_LITERAL(162, 2508, 9), // "Available"
QT_MOC_LITERAL(163, 2518, 4), // "Busy"
QT_MOC_LITERAL(164, 2523, 11), // "Unavailable"
QT_MOC_LITERAL(165, 2535, 15) // "ResourceMissing"

    },
    "QDeclarativeCamera\0errorChanged\0\0error\0"
    "QDeclarativeCamera::Error\0errorCode\0"
    "errorString\0errorOccurred\0deviceIdChanged\0"
    "positionChanged\0displayNameChanged\0"
    "orientationChanged\0captureModeChanged\0"
    "cameraStateChanged\0QDeclarativeCamera::State\0"
    "cameraStatusChanged\0lockStatusChanged\0"
    "opticalZoomChanged\0digitalZoomChanged\0"
    "maximumOpticalZoomChanged\0"
    "maximumDigitalZoomChanged\0mediaObjectChanged\0"
    "availabilityChanged\0Availability\0"
    "availability\0setCaptureMode\0CaptureMode\0"
    "mode\0start\0stop\0setCameraState\0State\0"
    "state\0searchAndLock\0unlock\0setOpticalZoom\0"
    "setDigitalZoom\0supportedViewfinderResolutions\0"
    "QJSValue\0minimumFrameRate\0maximumFrameRate\0"
    "supportedViewfinderFrameRateRanges\0"
    "resolution\0_q_updateState\0QCamera::State\0"
    "_q_errorOccurred\0QCamera::Error\0"
    "_q_availabilityChanged\0"
    "QMultimedia::AvailabilityStatus\0"
    "deviceId\0position\0Position\0displayName\0"
    "orientation\0captureMode\0cameraState\0"
    "cameraStatus\0Status\0lockStatus\0"
    "LockStatus\0Error\0opticalZoom\0"
    "maximumOpticalZoom\0digitalZoom\0"
    "maximumDigitalZoom\0mediaObject\0"
    "imageCapture\0QDeclarativeCameraCapture*\0"
    "videoRecorder\0QDeclarativeCameraRecorder*\0"
    "exposure\0QDeclarativeCameraExposure*\0"
    "flash\0QDeclarativeCameraFlash*\0focus\0"
    "QDeclarativeCameraFocus*\0imageProcessing\0"
    "QDeclarativeCameraImageProcessing*\0"
    "metaData\0QDeclarativeMediaMetaData*\0"
    "viewfinder\0QDeclarativeCameraViewfinder*\0"
    "UnspecifiedPosition\0BackFace\0FrontFace\0"
    "CaptureViewfinder\0CaptureStillImage\0"
    "CaptureVideo\0ActiveState\0LoadedState\0"
    "UnloadedState\0UnavailableStatus\0"
    "UnloadedStatus\0LoadingStatus\0"
    "UnloadingStatus\0LoadedStatus\0StandbyStatus\0"
    "StartingStatus\0StoppingStatus\0"
    "ActiveStatus\0Unlocked\0Searching\0Locked\0"
    "NoError\0CameraError\0InvalidRequestError\0"
    "ServiceMissingError\0NotSupportedFeatureError\0"
    "FlashMode\0FlashAuto\0FlashOff\0FlashOn\0"
    "FlashRedEyeReduction\0FlashFill\0"
    "FlashTorch\0FlashVideoLight\0"
    "FlashSlowSyncFrontCurtain\0"
    "FlashSlowSyncRearCurtain\0FlashManual\0"
    "ExposureMode\0ExposureAuto\0ExposureManual\0"
    "ExposurePortrait\0ExposureNight\0"
    "ExposureBacklight\0ExposureSpotlight\0"
    "ExposureSports\0ExposureSnow\0ExposureBeach\0"
    "ExposureLargeAperture\0ExposureSmallAperture\0"
    "ExposureAction\0ExposureLandscape\0"
    "ExposureNightPortrait\0ExposureTheatre\0"
    "ExposureSunset\0ExposureSteadyPhoto\0"
    "ExposureFireworks\0ExposureParty\0"
    "ExposureCandlelight\0ExposureBarcode\0"
    "ExposureModeVendor\0MeteringMode\0"
    "MeteringMatrix\0MeteringAverage\0"
    "MeteringSpot\0FocusMode\0FocusManual\0"
    "FocusHyperfocal\0FocusInfinity\0FocusAuto\0"
    "FocusContinuous\0FocusMacro\0FocusPointMode\0"
    "FocusPointAuto\0FocusPointCenter\0"
    "FocusPointFaceDetection\0FocusPointCustom\0"
    "FocusAreaStatus\0FocusAreaUnused\0"
    "FocusAreaSelected\0FocusAreaFocused\0"
    "Available\0Busy\0Unavailable\0ResourceMissing"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QDeclarativeCamera[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      33,   14, // methods
      24,  287, // properties
      13,  407, // enums/sets
       0,    0, // constructors
       0,       // flags
      17,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  212,    2, 0x06 /* Public */,
       3,    2,  213,    2, 0x06 /* Public */,
       7,    2,  218,    2, 0x86 /* Public | MethodRevisioned */,
       8,    0,  223,    2, 0x86 /* Public | MethodRevisioned */,
       9,    0,  224,    2, 0x86 /* Public | MethodRevisioned */,
      10,    0,  225,    2, 0x86 /* Public | MethodRevisioned */,
      11,    0,  226,    2, 0x86 /* Public | MethodRevisioned */,
      12,    0,  227,    2, 0x06 /* Public */,
      13,    1,  228,    2, 0x06 /* Public */,
      15,    0,  231,    2, 0x06 /* Public */,
      16,    0,  232,    2, 0x06 /* Public */,
      17,    1,  233,    2, 0x06 /* Public */,
      18,    1,  236,    2, 0x06 /* Public */,
      19,    1,  239,    2, 0x06 /* Public */,
      20,    1,  242,    2, 0x06 /* Public */,
      21,    0,  245,    2, 0x06 /* Public */,
      22,    1,  246,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      25,    1,  249,    2, 0x0a /* Public */,
      28,    0,  252,    2, 0x0a /* Public */,
      29,    0,  253,    2, 0x0a /* Public */,
      30,    1,  254,    2, 0x0a /* Public */,
      33,    0,  257,    2, 0x0a /* Public */,
      34,    0,  258,    2, 0x0a /* Public */,
      35,    1,  259,    2, 0x0a /* Public */,
      36,    1,  262,    2, 0x0a /* Public */,
      37,    2,  265,    2, 0x8a /* Public | MethodRevisioned */,
      37,    1,  270,    2, 0xaa /* Public | MethodCloned | MethodRevisioned */,
      37,    0,  273,    2, 0xaa /* Public | MethodCloned | MethodRevisioned */,
      41,    1,  274,    2, 0x8a /* Public | MethodRevisioned */,
      41,    0,  277,    2, 0xaa /* Public | MethodCloned | MethodRevisioned */,
      43,    1,  278,    2, 0x08 /* Private */,
      45,    1,  281,    2, 0x08 /* Private */,
      47,    1,  284,    2, 0x08 /* Private */,

 // signals: revision
       0,
       0,
      15,
       1,
       1,
       1,
       1,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,

 // slots: revision
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       2,
       2,
       2,
       2,
       2,
       0,
       0,
       0,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, QMetaType::QString,    5,    6,
    QMetaType::Void, 0x80000000 | 4, QMetaType::QString,    5,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QReal,    2,
    QMetaType::Void, QMetaType::QReal,    2,
    QMetaType::Void, QMetaType::QReal,    2,
    QMetaType::Void, QMetaType::QReal,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 23,   24,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 26,   27,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 31,   32,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QReal,    2,
    QMetaType::Void, QMetaType::QReal,    2,
    0x80000000 | 38, QMetaType::QReal, QMetaType::QReal,   39,   40,
    0x80000000 | 38, QMetaType::QReal,   39,
    0x80000000 | 38,
    0x80000000 | 38, 0x80000000 | 38,   42,
    0x80000000 | 38,
    QMetaType::Void, 0x80000000 | 44,    2,
    QMetaType::Void, 0x80000000 | 46,    2,
    QMetaType::Void, 0x80000000 | 48,    2,

 // properties: name, type, flags
      49, QMetaType::QString, 0x00c95103,
      50, 0x80000000 | 51, 0x00c9510b,
      52, QMetaType::QString, 0x00c95001,
      53, QMetaType::Int, 0x00c95001,
      54, 0x80000000 | 26, 0x0049510b,
      55, 0x80000000 | 31, 0x0049510b,
      56, 0x80000000 | 57, 0x00495009,
      58, 0x80000000 | 59, 0x00495009,
       5, 0x80000000 | 60, 0x00495009,
       6, QMetaType::QString, 0x00495001,
      24, 0x80000000 | 23, 0x00495009,
      61, QMetaType::QReal, 0x00495103,
      62, QMetaType::QReal, 0x00495001,
      63, QMetaType::QReal, 0x00495103,
      64, QMetaType::QReal, 0x00495001,
      65, QMetaType::QObjectStar, 0x00490001,
      66, 0x80000000 | 67, 0x00095409,
      68, 0x80000000 | 69, 0x00095409,
      70, 0x80000000 | 71, 0x00095409,
      72, 0x80000000 | 73, 0x00095409,
      74, 0x80000000 | 75, 0x00095409,
      76, 0x80000000 | 77, 0x00095409,
      78, 0x80000000 | 79, 0x00895409,
      80, 0x80000000 | 81, 0x00895409,

 // properties: notify_signal_id
       3,
       4,
       5,
       6,
       7,
       8,
       9,
      10,
       0,
       0,
      16,
      11,
      13,
      12,
      14,
      15,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,

 // properties: revision
       1,
       1,
       1,
       1,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       1,
       1,

 // enums: name, alias, flags, count, data
      51,   51, 0x0,    3,  472,
      26,   26, 0x0,    3,  478,
      31,   31, 0x0,    3,  484,
      57,   57, 0x0,    9,  490,
      59,   59, 0x0,    3,  508,
      60,   60, 0x0,    5,  514,
     108,  108, 0x0,   10,  524,
     119,  119, 0x0,   22,  544,
     142,  142, 0x0,    3,  588,
     146,  146, 0x0,    6,  594,
     153,  153, 0x0,    4,  606,
     158,  158, 0x0,    3,  614,
      23,   23, 0x0,    4,  620,

 // enum data: key, value
      82, uint(QDeclarativeCamera::UnspecifiedPosition),
      83, uint(QDeclarativeCamera::BackFace),
      84, uint(QDeclarativeCamera::FrontFace),
      85, uint(QDeclarativeCamera::CaptureViewfinder),
      86, uint(QDeclarativeCamera::CaptureStillImage),
      87, uint(QDeclarativeCamera::CaptureVideo),
      88, uint(QDeclarativeCamera::ActiveState),
      89, uint(QDeclarativeCamera::LoadedState),
      90, uint(QDeclarativeCamera::UnloadedState),
      91, uint(QDeclarativeCamera::UnavailableStatus),
      92, uint(QDeclarativeCamera::UnloadedStatus),
      93, uint(QDeclarativeCamera::LoadingStatus),
      94, uint(QDeclarativeCamera::UnloadingStatus),
      95, uint(QDeclarativeCamera::LoadedStatus),
      96, uint(QDeclarativeCamera::StandbyStatus),
      97, uint(QDeclarativeCamera::StartingStatus),
      98, uint(QDeclarativeCamera::StoppingStatus),
      99, uint(QDeclarativeCamera::ActiveStatus),
     100, uint(QDeclarativeCamera::Unlocked),
     101, uint(QDeclarativeCamera::Searching),
     102, uint(QDeclarativeCamera::Locked),
     103, uint(QDeclarativeCamera::NoError),
     104, uint(QDeclarativeCamera::CameraError),
     105, uint(QDeclarativeCamera::InvalidRequestError),
     106, uint(QDeclarativeCamera::ServiceMissingError),
     107, uint(QDeclarativeCamera::NotSupportedFeatureError),
     109, uint(QDeclarativeCamera::FlashAuto),
     110, uint(QDeclarativeCamera::FlashOff),
     111, uint(QDeclarativeCamera::FlashOn),
     112, uint(QDeclarativeCamera::FlashRedEyeReduction),
     113, uint(QDeclarativeCamera::FlashFill),
     114, uint(QDeclarativeCamera::FlashTorch),
     115, uint(QDeclarativeCamera::FlashVideoLight),
     116, uint(QDeclarativeCamera::FlashSlowSyncFrontCurtain),
     117, uint(QDeclarativeCamera::FlashSlowSyncRearCurtain),
     118, uint(QDeclarativeCamera::FlashManual),
     120, uint(QDeclarativeCamera::ExposureAuto),
     121, uint(QDeclarativeCamera::ExposureManual),
     122, uint(QDeclarativeCamera::ExposurePortrait),
     123, uint(QDeclarativeCamera::ExposureNight),
     124, uint(QDeclarativeCamera::ExposureBacklight),
     125, uint(QDeclarativeCamera::ExposureSpotlight),
     126, uint(QDeclarativeCamera::ExposureSports),
     127, uint(QDeclarativeCamera::ExposureSnow),
     128, uint(QDeclarativeCamera::ExposureBeach),
     129, uint(QDeclarativeCamera::ExposureLargeAperture),
     130, uint(QDeclarativeCamera::ExposureSmallAperture),
     131, uint(QDeclarativeCamera::ExposureAction),
     132, uint(QDeclarativeCamera::ExposureLandscape),
     133, uint(QDeclarativeCamera::ExposureNightPortrait),
     134, uint(QDeclarativeCamera::ExposureTheatre),
     135, uint(QDeclarativeCamera::ExposureSunset),
     136, uint(QDeclarativeCamera::ExposureSteadyPhoto),
     137, uint(QDeclarativeCamera::ExposureFireworks),
     138, uint(QDeclarativeCamera::ExposureParty),
     139, uint(QDeclarativeCamera::ExposureCandlelight),
     140, uint(QDeclarativeCamera::ExposureBarcode),
     141, uint(QDeclarativeCamera::ExposureModeVendor),
     143, uint(QDeclarativeCamera::MeteringMatrix),
     144, uint(QDeclarativeCamera::MeteringAverage),
     145, uint(QDeclarativeCamera::MeteringSpot),
     147, uint(QDeclarativeCamera::FocusManual),
     148, uint(QDeclarativeCamera::FocusHyperfocal),
     149, uint(QDeclarativeCamera::FocusInfinity),
     150, uint(QDeclarativeCamera::FocusAuto),
     151, uint(QDeclarativeCamera::FocusContinuous),
     152, uint(QDeclarativeCamera::FocusMacro),
     154, uint(QDeclarativeCamera::FocusPointAuto),
     155, uint(QDeclarativeCamera::FocusPointCenter),
     156, uint(QDeclarativeCamera::FocusPointFaceDetection),
     157, uint(QDeclarativeCamera::FocusPointCustom),
     159, uint(QDeclarativeCamera::FocusAreaUnused),
     160, uint(QDeclarativeCamera::FocusAreaSelected),
     161, uint(QDeclarativeCamera::FocusAreaFocused),
     162, uint(QDeclarativeCamera::Available),
     163, uint(QDeclarativeCamera::Busy),
     164, uint(QDeclarativeCamera::Unavailable),
     165, uint(QDeclarativeCamera::ResourceMissing),

       0        // eod
};

void QDeclarativeCamera::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QDeclarativeCamera *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->errorChanged(); break;
        case 1: _t->error((*reinterpret_cast< QDeclarativeCamera::Error(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 2: _t->errorOccurred((*reinterpret_cast< QDeclarativeCamera::Error(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->deviceIdChanged(); break;
        case 4: _t->positionChanged(); break;
        case 5: _t->displayNameChanged(); break;
        case 6: _t->orientationChanged(); break;
        case 7: _t->captureModeChanged(); break;
        case 8: _t->cameraStateChanged((*reinterpret_cast< QDeclarativeCamera::State(*)>(_a[1]))); break;
        case 9: _t->cameraStatusChanged(); break;
        case 10: _t->lockStatusChanged(); break;
        case 11: _t->opticalZoomChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 12: _t->digitalZoomChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 13: _t->maximumOpticalZoomChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 14: _t->maximumDigitalZoomChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 15: _t->mediaObjectChanged(); break;
        case 16: _t->availabilityChanged((*reinterpret_cast< Availability(*)>(_a[1]))); break;
        case 17: _t->setCaptureMode((*reinterpret_cast< CaptureMode(*)>(_a[1]))); break;
        case 18: _t->start(); break;
        case 19: _t->stop(); break;
        case 20: _t->setCameraState((*reinterpret_cast< State(*)>(_a[1]))); break;
        case 21: _t->searchAndLock(); break;
        case 22: _t->unlock(); break;
        case 23: _t->setOpticalZoom((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 24: _t->setDigitalZoom((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 25: { QJSValue _r = _t->supportedViewfinderResolutions((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 26: { QJSValue _r = _t->supportedViewfinderResolutions((*reinterpret_cast< qreal(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 27: { QJSValue _r = _t->supportedViewfinderResolutions();
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 28: { QJSValue _r = _t->supportedViewfinderFrameRateRanges((*reinterpret_cast< const QJSValue(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 29: { QJSValue _r = _t->supportedViewfinderFrameRateRanges();
            if (_a[0]) *reinterpret_cast< QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->_q_updateState((*reinterpret_cast< QCamera::State(*)>(_a[1]))); break;
        case 31: _t->_q_errorOccurred((*reinterpret_cast< QCamera::Error(*)>(_a[1]))); break;
        case 32: _t->_q_availabilityChanged((*reinterpret_cast< QMultimedia::AvailabilityStatus(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QCamera::State >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QCamera::Error >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QMultimedia::AvailabilityStatus >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QDeclarativeCamera::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::errorChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)(QDeclarativeCamera::Error , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::error)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)(QDeclarativeCamera::Error , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::errorOccurred)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::deviceIdChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::positionChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::displayNameChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::orientationChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::captureModeChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)(QDeclarativeCamera::State );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::cameraStateChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::cameraStatusChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::lockStatusChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)(qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::opticalZoomChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)(qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::digitalZoomChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)(qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::maximumOpticalZoomChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)(qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::maximumDigitalZoomChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::mediaObjectChanged)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (QDeclarativeCamera::*)(Availability );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QDeclarativeCamera::availabilityChanged)) {
                *result = 16;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 16:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDeclarativeCameraCapture* >(); break;
        case 17:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDeclarativeCameraRecorder* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QDeclarativeCamera *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->deviceId(); break;
        case 1: *reinterpret_cast< Position*>(_v) = _t->position(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->displayName(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->orientation(); break;
        case 4: *reinterpret_cast< CaptureMode*>(_v) = _t->captureMode(); break;
        case 5: *reinterpret_cast< State*>(_v) = _t->cameraState(); break;
        case 6: *reinterpret_cast< Status*>(_v) = _t->cameraStatus(); break;
        case 7: *reinterpret_cast< LockStatus*>(_v) = _t->lockStatus(); break;
        case 8: *reinterpret_cast< Error*>(_v) = _t->errorCode(); break;
        case 9: *reinterpret_cast< QString*>(_v) = _t->errorString(); break;
        case 10: *reinterpret_cast< Availability*>(_v) = _t->availability(); break;
        case 11: *reinterpret_cast< qreal*>(_v) = _t->opticalZoom(); break;
        case 12: *reinterpret_cast< qreal*>(_v) = _t->maximumOpticalZoom(); break;
        case 13: *reinterpret_cast< qreal*>(_v) = _t->digitalZoom(); break;
        case 14: *reinterpret_cast< qreal*>(_v) = _t->maximumDigitalZoom(); break;
        case 15: *reinterpret_cast< QObject**>(_v) = _t->mediaObject(); break;
        case 16: *reinterpret_cast< QDeclarativeCameraCapture**>(_v) = _t->imageCapture(); break;
        case 17: *reinterpret_cast< QDeclarativeCameraRecorder**>(_v) = _t->videoRecorder(); break;
        case 18: *reinterpret_cast< QDeclarativeCameraExposure**>(_v) = _t->exposure(); break;
        case 19: *reinterpret_cast< QDeclarativeCameraFlash**>(_v) = _t->flash(); break;
        case 20: *reinterpret_cast< QDeclarativeCameraFocus**>(_v) = _t->focus(); break;
        case 21: *reinterpret_cast< QDeclarativeCameraImageProcessing**>(_v) = _t->imageProcessing(); break;
        case 22: *reinterpret_cast< QDeclarativeMediaMetaData**>(_v) = _t->metaData(); break;
        case 23: *reinterpret_cast< QDeclarativeCameraViewfinder**>(_v) = _t->viewfinder(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QDeclarativeCamera *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDeviceId(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setPosition(*reinterpret_cast< Position*>(_v)); break;
        case 4: _t->setCaptureMode(*reinterpret_cast< CaptureMode*>(_v)); break;
        case 5: _t->setCameraState(*reinterpret_cast< State*>(_v)); break;
        case 11: _t->setOpticalZoom(*reinterpret_cast< qreal*>(_v)); break;
        case 13: _t->setDigitalZoom(*reinterpret_cast< qreal*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QDeclarativeCamera::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QDeclarativeCamera.data,
    qt_meta_data_QDeclarativeCamera,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QDeclarativeCamera::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QDeclarativeCamera::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QDeclarativeCamera.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int QDeclarativeCamera::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 24;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 24;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 24;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 24;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 24;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QDeclarativeCamera::errorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QDeclarativeCamera::error(QDeclarativeCamera::Error _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QDeclarativeCamera::errorOccurred(QDeclarativeCamera::Error _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QDeclarativeCamera::deviceIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QDeclarativeCamera::positionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QDeclarativeCamera::displayNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QDeclarativeCamera::orientationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QDeclarativeCamera::captureModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QDeclarativeCamera::cameraStateChanged(QDeclarativeCamera::State _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void QDeclarativeCamera::cameraStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QDeclarativeCamera::lockStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QDeclarativeCamera::opticalZoomChanged(qreal _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void QDeclarativeCamera::digitalZoomChanged(qreal _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void QDeclarativeCamera::maximumOpticalZoomChanged(qreal _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void QDeclarativeCamera::maximumDigitalZoomChanged(qreal _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void QDeclarativeCamera::mediaObjectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void QDeclarativeCamera::availabilityChanged(Availability _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
