/****************************************************************************
** Meta object code from reading C++ file 'qgstreamerrecordercontrol.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../git/src/plugins/gstreamer/mediacapture/qgstreamerrecordercontrol.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qgstreamerrecordercontrol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QGstreamerRecorderControl_t {
    QByteArrayData data[15];
    char stringdata0[157];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QGstreamerRecorderControl_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QGstreamerRecorderControl_t qt_meta_stringdata_QGstreamerRecorderControl = {
    {
QT_MOC_LITERAL(0, 0, 25), // "QGstreamerRecorderControl"
QT_MOC_LITERAL(1, 26, 8), // "setState"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 21), // "QMediaRecorder::State"
QT_MOC_LITERAL(4, 58, 5), // "state"
QT_MOC_LITERAL(5, 64, 6), // "record"
QT_MOC_LITERAL(6, 71, 5), // "pause"
QT_MOC_LITERAL(7, 77, 4), // "stop"
QT_MOC_LITERAL(8, 82, 8), // "setMuted"
QT_MOC_LITERAL(9, 91, 9), // "setVolume"
QT_MOC_LITERAL(10, 101, 6), // "volume"
QT_MOC_LITERAL(11, 108, 12), // "updateStatus"
QT_MOC_LITERAL(12, 121, 18), // "handleSessionError"
QT_MOC_LITERAL(13, 140, 4), // "code"
QT_MOC_LITERAL(14, 145, 11) // "description"

    },
    "QGstreamerRecorderControl\0setState\0\0"
    "QMediaRecorder::State\0state\0record\0"
    "pause\0stop\0setMuted\0setVolume\0volume\0"
    "updateStatus\0handleSessionError\0code\0"
    "description"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QGstreamerRecorderControl[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x0a /* Public */,
       5,    0,   57,    2, 0x0a /* Public */,
       6,    0,   58,    2, 0x0a /* Public */,
       7,    0,   59,    2, 0x0a /* Public */,
       8,    1,   60,    2, 0x0a /* Public */,
       9,    1,   63,    2, 0x0a /* Public */,
      11,    0,   66,    2, 0x08 /* Private */,
      12,    2,   67,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QReal,   10,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   13,   14,

       0        // eod
};

void QGstreamerRecorderControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QGstreamerRecorderControl *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setState((*reinterpret_cast< QMediaRecorder::State(*)>(_a[1]))); break;
        case 1: _t->record(); break;
        case 2: _t->pause(); break;
        case 3: _t->stop(); break;
        case 4: _t->setMuted((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->setVolume((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 6: _t->updateStatus(); break;
        case 7: _t->handleSessionError((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QMediaRecorder::State >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QGstreamerRecorderControl::staticMetaObject = { {
    QMetaObject::SuperData::link<QMediaRecorderControl::staticMetaObject>(),
    qt_meta_stringdata_QGstreamerRecorderControl.data,
    qt_meta_data_QGstreamerRecorderControl,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QGstreamerRecorderControl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QGstreamerRecorderControl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QGstreamerRecorderControl.stringdata0))
        return static_cast<void*>(this);
    return QMediaRecorderControl::qt_metacast(_clname);
}

int QGstreamerRecorderControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMediaRecorderControl::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
